# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gcg.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'gcg.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import data_room_pb2 as data__room__pb2
from . import identity_endorsement_pb2 as identity__endorsement__pb2
from . import release_policy_pb2 as release__policy__pb2
from . import secret_store_pb2 as secret__store__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tgcg.proto\x12\x03gcg\x1a\x0f\x64\x61ta_room.proto\x1a\x1aidentity_endorsement.proto\x1a\x14release_policy.proto\x1a\x12secret_store.proto\"\x82\x0e\n\nGcgRequest\x12\x1f\n\x08userAuth\x18\x01 \x01(\x0b\x32\r.gcg.UserAuth\x12;\n\x15\x63reateDataRoomRequest\x18\x02 \x01(\x0b\x32\x1a.gcg.CreateDataRoomRequestH\x00\x12?\n\x17retrieveDataRoomRequest\x18\x03 \x01(\x0b\x32\x1c.gcg.RetrieveDataRoomRequestH\x00\x12g\n+retrieveCurrentDataRoomConfigurationRequest\x18\x04 \x01(\x0b\x32\x30.gcg.RetrieveCurrentDataRoomConfigurationRequestH\x00\x12K\n\x1dretrieveDataRoomStatusRequest\x18\x05 \x01(\x0b\x32\".gcg.RetrieveDataRoomStatusRequestH\x00\x12G\n\x1bupdateDataRoomStatusRequest\x18\x06 \x01(\x0b\x32 .gcg.UpdateDataRoomStatusRequestH\x00\x12?\n\x17retrieveAuditLogRequest\x18\x07 \x01(\x0b\x32\x1c.gcg.RetrieveAuditLogRequestH\x00\x12O\n\x1fpublishDatasetToDataRoomRequest\x18\x08 \x01(\x0b\x32$.gcg.PublishDatasetToDataRoomRequestH\x00\x12Q\n retrievePublishedDatasetsRequest\x18\t \x01(\x0b\x32%.gcg.RetrievePublishedDatasetsRequestH\x00\x12K\n\x1dremovePublishedDatasetRequest\x18\n \x01(\x0b\x32\".gcg.RemovePublishedDatasetRequestH\x00\x12;\n\x15\x65xecuteComputeRequest\x18\x0b \x01(\x0b\x32\x1a.gcg.ExecuteComputeRequestH\x00\x12\x31\n\x10jobStatusRequest\x18\x0c \x01(\x0b\x32\x15.gcg.JobStatusRequestH\x00\x12\x33\n\x11getResultsRequest\x18\r \x01(\x0b\x32\x16.gcg.GetResultsRequestH\x00\x12Q\n createConfigurationCommitRequest\x18\x0e \x01(\x0b\x32%.gcg.CreateConfigurationCommitRequestH\x00\x12U\n\"retrieveConfigurationCommitRequest\x18\x0f \x01(\x0b\x32\'.gcg.RetrieveConfigurationCommitRequestH\x00\x12Q\n executeDevelopmentComputeRequest\x18\x10 \x01(\x0b\x32%.gcg.ExecuteDevelopmentComputeRequestH\x00\x12[\n%generateMergeApprovalSignatureRequest\x18\x11 \x01(\x0b\x32*.gcg.GenerateMergeApprovalSignatureRequestH\x00\x12O\n\x1fmergeConfigurationCommitRequest\x18\x12 \x01(\x0b\x32$.gcg.MergeConfigurationCommitRequestH\x00\x12g\n+retrieveConfigurationCommitApproversRequest\x18\x13 \x01(\x0b\x32\x30.gcg.RetrieveConfigurationCommitApproversRequestH\x00\x12\x41\n\x18\x63\x61sAuxiliaryStateRequest\x18\x14 \x01(\x0b\x32\x1d.gcg.CasAuxiliaryStateRequestH\x00\x12\x43\n\x19readAuxiliaryStateRequest\x18\x15 \x01(\x0b\x32\x1e.gcg.ReadAuxiliaryStateRequestH\x00\x12O\n\x1fretrieveUsedAirlockQuotaRequest\x18\x16 \x01(\x0b\x32$.gcg.RetrieveUsedAirlockQuotaRequestH\x00\x12;\n\x15getResultsSizeRequest\x18\x17 \x01(\x0b\x32\x1a.gcg.GetResultsSizeRequestH\x00\x12\x46\n\x12\x65ndorsementRequest\x18\x65 \x01(\x0b\x32(.identity_endorsement.EndorsementRequestH\x00\x42\r\n\x0bgcg_request\"\x9c\x0e\n\x0bGcgResponse\x12\x11\n\x07\x66\x61ilure\x18\x01 \x01(\tH\x00\x12=\n\x16\x63reateDataRoomResponse\x18\x02 \x01(\x0b\x32\x1b.gcg.CreateDataRoomResponseH\x00\x12\x41\n\x18retrieveDataRoomResponse\x18\x03 \x01(\x0b\x32\x1d.gcg.RetrieveDataRoomResponseH\x00\x12i\n,retrieveCurrentDataRoomConfigurationResponse\x18\x04 \x01(\x0b\x32\x31.gcg.RetrieveCurrentDataRoomConfigurationResponseH\x00\x12M\n\x1eretrieveDataRoomStatusResponse\x18\x05 \x01(\x0b\x32#.gcg.RetrieveDataRoomStatusResponseH\x00\x12I\n\x1cupdateDataRoomStatusResponse\x18\x06 \x01(\x0b\x32!.gcg.UpdateDataRoomStatusResponseH\x00\x12\x41\n\x18retrieveAuditLogResponse\x18\x07 \x01(\x0b\x32\x1d.gcg.RetrieveAuditLogResponseH\x00\x12Q\n publishDatasetToDataRoomResponse\x18\x08 \x01(\x0b\x32%.gcg.PublishDatasetToDataRoomResponseH\x00\x12S\n!retrievePublishedDatasetsResponse\x18\t \x01(\x0b\x32&.gcg.RetrievePublishedDatasetsResponseH\x00\x12M\n\x1eremovePublishedDatasetResponse\x18\n \x01(\x0b\x32#.gcg.RemovePublishedDatasetResponseH\x00\x12=\n\x16\x65xecuteComputeResponse\x18\x0b \x01(\x0b\x32\x1b.gcg.ExecuteComputeResponseH\x00\x12\x33\n\x11jobStatusResponse\x18\x0c \x01(\x0b\x32\x16.gcg.JobStatusResponseH\x00\x12?\n\x17getResultsResponseChunk\x18\r \x01(\x0b\x32\x1c.gcg.GetResultsResponseChunkH\x00\x12\x41\n\x18getResultsResponseFooter\x18\x0e \x01(\x0b\x32\x1d.gcg.GetResultsResponseFooterH\x00\x12S\n!createConfigurationCommitResponse\x18\x0f \x01(\x0b\x32&.gcg.CreateConfigurationCommitResponseH\x00\x12W\n#retrieveConfigurationCommitResponse\x18\x10 \x01(\x0b\x32(.gcg.RetrieveConfigurationCommitResponseH\x00\x12]\n&generateMergeApprovalSignatureResponse\x18\x11 \x01(\x0b\x32+.gcg.GenerateMergeApprovalSignatureResponseH\x00\x12Q\n mergeConfigurationCommitResponse\x18\x12 \x01(\x0b\x32%.gcg.MergeConfigurationCommitResponseH\x00\x12i\n,retrieveConfigurationCommitApproversResponse\x18\x13 \x01(\x0b\x32\x31.gcg.RetrieveConfigurationCommitApproversResponseH\x00\x12\x43\n\x19\x63\x61sAuxiliaryStateResponse\x18\x14 \x01(\x0b\x32\x1e.gcg.CasAuxiliaryStateResponseH\x00\x12\x45\n\x1areadAuxiliaryStateResponse\x18\x15 \x01(\x0b\x32\x1f.gcg.ReadAuxiliaryStateResponseH\x00\x12Q\n retrieveUsedAirlockQuotaResponse\x18\x16 \x01(\x0b\x32%.gcg.RetrieveUsedAirlockQuotaResponseH\x00\x12=\n\x16getResultsSizeResponse\x18\x17 \x01(\x0b\x32\x1b.gcg.GetResultsSizeResponseH\x00\x12H\n\x13\x65ndorsementResponse\x18\x65 \x01(\x0b\x32).identity_endorsement.EndorsementResponseH\x00\x42\x0e\n\x0cgcg_response\"i\n\x08UserAuth\x12\x15\n\x03pki\x18\x01 \x01(\x0b\x32\x08.gcg.Pki\x12\x46\n\x13\x65nclaveEndorsements\x18\x02 \x01(\x0b\x32).identity_endorsement.EnclaveEndorsements\"=\n\x03Pki\x12\x14\n\x0c\x63\x65rtChainPem\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12\r\n\x05idMac\x18\x03 \x01(\x0c\"\xb4\x01\n\x15\x43reateDataRoomRequest\x12%\n\x08\x64\x61taRoom\x18\x01 \x01(\x0b\x32\x13.data_room.DataRoom\x12$\n\x17highLevelRepresentation\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x12\x1d\n\x10\x64\x61taRoomMetadata\x18\x03 \x01(\x0cH\x01\x88\x01\x01\x42\x1a\n\x18_highLevelRepresentationB\x13\n\x11_dataRoomMetadata\"\x8c\x01\n\x16\x43reateDataRoomResponse\x12\x14\n\ndataRoomId\x18\x01 \x01(\x0cH\x00\x12?\n\x17\x64\x61taRoomValidationError\x18\x02 \x01(\x0b\x32\x1c.gcg.DataRoomValidationErrorH\x00\x42\x1b\n\x19\x63reate_data_room_response\"\xc6\x02\n\x17\x44\x61taRoomValidationError\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x1c\n\x0fpermissionIndex\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x1a\n\rcomputeNodeId\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1d\n\x10userPermissionId\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\'\n\x1a\x61ttestationSpecificationId\x18\x05 \x01(\tH\x03\x88\x01\x01\x12#\n\x16\x61uthenticationMethodId\x18\x06 \x01(\tH\x04\x88\x01\x01\x42\x12\n\x10_permissionIndexB\x10\n\x0e_computeNodeIdB\x13\n\x11_userPermissionIdB\x1d\n\x1b_attestationSpecificationIdB\x19\n\x17_authenticationMethodId\"\x80\x01\n\x1fPublishDatasetToDataRoomRequest\x12\x13\n\x0b\x64\x61tasetHash\x18\x01 \x01(\x0c\x12\x12\n\ndataRoomId\x18\x02 \x01(\x0c\x12\x0e\n\x06leafId\x18\x03 \x01(\t\x12\x15\n\rencryptionKey\x18\x04 \x01(\x0c\x12\r\n\x05scope\x18\x05 \x01(\x0c\"\"\n PublishDatasetToDataRoomResponse\"\xe2\x02\n\x15\x45xecuteComputeRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\x16\n\x0e\x63omputeNodeIds\x18\x02 \x03(\t\x12\x10\n\x08isDryRun\x18\x03 \x01(\x08\x12\r\n\x05scope\x18\x04 \x01(\x0c\x12>\n\nparameters\x18\x05 \x03(\x0b\x32*.gcg.ExecuteComputeRequest.ParametersEntry\x12\x42\n\x0ctestDatasets\x18\x06 \x03(\x0b\x32,.gcg.ExecuteComputeRequest.TestDatasetsEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x45\n\x11TestDatasetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.gcg.TestDataset:\x02\x38\x01\"\x8e\x03\n ExecuteDevelopmentComputeRequest\x12\x1d\n\x15\x63onfigurationCommitId\x18\x01 \x01(\x0c\x12\x16\n\x0e\x63omputeNodeIds\x18\x02 \x03(\t\x12\x10\n\x08isDryRun\x18\x03 \x01(\x08\x12\r\n\x05scope\x18\x04 \x01(\x0c\x12I\n\nparameters\x18\x05 \x03(\x0b\x32\x35.gcg.ExecuteDevelopmentComputeRequest.ParametersEntry\x12M\n\x0ctestDatasets\x18\x06 \x03(\x0b\x32\x37.gcg.ExecuteDevelopmentComputeRequest.TestDatasetsEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x45\n\x11TestDatasetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.gcg.TestDataset:\x02\x38\x01\":\n\x0bTestDataset\x12\x15\n\rencryptionKey\x18\x01 \x01(\x0c\x12\x14\n\x0cmanifestHash\x18\x02 \x01(\x0c\"\'\n\x16\x45xecuteComputeResponse\x12\r\n\x05jobId\x18\x01 \x01(\x0c\"!\n\x10JobStatusRequest\x12\r\n\x05jobId\x18\x01 \x01(\x0c\"3\n\x11JobStatusResponse\x12\x1e\n\x16\x63ompleteComputeNodeIds\x18\x01 \x03(\t\"9\n\x11GetResultsRequest\x12\r\n\x05jobId\x18\x01 \x01(\x0c\x12\x15\n\rcomputeNodeId\x18\x02 \x01(\t\"=\n\x15GetResultsSizeRequest\x12\r\n\x05jobId\x18\x01 \x01(\x0c\x12\x15\n\rcomputeNodeId\x18\x02 \x01(\t\"\'\n\x17GetResultsResponseChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x1a\n\x18GetResultsResponseFooter\"-\n\x17RetrieveDataRoomRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"\xb4\x01\n\x18RetrieveDataRoomResponse\x12%\n\x08\x64\x61taRoom\x18\x01 \x01(\x0b\x32\x13.data_room.DataRoom\x12/\n\x07\x63ommits\x18\x02 \x03(\x0b\x32\x1e.data_room.ConfigurationCommit\x12$\n\x17highLevelRepresentation\x18\x03 \x01(\x0cH\x00\x88\x01\x01\x42\x1a\n\x18_highLevelRepresentation\"-\n\x17RetrieveAuditLogRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"\'\n\x18RetrieveAuditLogResponse\x12\x0b\n\x03log\x18\x01 \x01(\x0c\"3\n\x1dRetrieveDataRoomStatusRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"E\n\x1eRetrieveDataRoomStatusResponse\x12#\n\x06status\x18\x01 \x01(\x0e\x32\x13.gcg.DataRoomStatus\"V\n\x1bUpdateDataRoomStatusRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12#\n\x06status\x18\x02 \x01(\x0e\x32\x13.gcg.DataRoomStatus\"\x1e\n\x1cUpdateDataRoomStatusResponse\"6\n RetrievePublishedDatasetsRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"X\n\x10PublishedDataset\x12\x0e\n\x06leafId\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x12\x13\n\x0b\x64\x61tasetHash\x18\x04 \x01(\x0c\"U\n!RetrievePublishedDatasetsResponse\x12\x30\n\x11publishedDatasets\x18\x01 \x03(\x0b\x32\x15.gcg.PublishedDataset\"C\n\x1dRemovePublishedDatasetRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\x0e\n\x06leafId\x18\x02 \x01(\t\" \n\x1eRemovePublishedDatasetResponse\"\x94\x01\n CreateConfigurationCommitRequest\x12.\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x1e.data_room.ConfigurationCommit\x12$\n\x17highLevelRepresentation\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x1a\n\x18_highLevelRepresentation\"5\n!CreateConfigurationCommitResponse\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\"9\n%GenerateMergeApprovalSignatureRequest\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\";\n&GenerateMergeApprovalSignatureResponse\x12\x11\n\tsignature\x18\x01 \x01(\x0c\"\xa0\x02\n\x1fMergeConfigurationCommitRequest\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\x12X\n\x12\x61pprovalSignatures\x18\x02 \x03(\x0b\x32<.gcg.MergeConfigurationCommitRequest.ApprovalSignaturesEntry\x12/\n\"newDataRoomHighLevelRepresentation\x18\x03 \x01(\x0cH\x00\x88\x01\x01\x1a\x39\n\x17\x41pprovalSignaturesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x42%\n#_newDataRoomHighLevelRepresentation\"A\n+RetrieveCurrentDataRoomConfigurationRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"t\n,RetrieveCurrentDataRoomConfigurationResponse\x12\x37\n\rconfiguration\x18\x01 \x01(\x0b\x32 .data_room.DataRoomConfiguration\x12\x0b\n\x03pin\x18\x02 \x01(\x0c\"?\n+RetrieveConfigurationCommitApproversRequest\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\"A\n,RetrieveConfigurationCommitApproversResponse\x12\x11\n\tapprovers\x18\x01 \x03(\t\"6\n\"RetrieveConfigurationCommitRequest\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\"\x97\x01\n#RetrieveConfigurationCommitResponse\x12.\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x1e.data_room.ConfigurationCommit\x12$\n\x17highLevelRepresentation\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x1a\n\x18_highLevelRepresentation\"[\n\x18\x43\x61sAuxiliaryStateRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\r\n\x05index\x18\x02 \x01(\x04\x12\x12\n\x05value\x18\x03 \x01(\x0cH\x00\x88\x01\x01\x42\x08\n\x06_value\"Y\n\x19\x43\x61sAuxiliaryStateResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05index\x18\x02 \x01(\x04\x12\x12\n\x05value\x18\x03 \x01(\x0cH\x00\x88\x01\x01\x42\x08\n\x06_value\"/\n\x19ReadAuxiliaryStateRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"F\n\x1aReadAuxiliaryStateResponse\x12(\n\x06values\x18\x02 \x03(\x0b\x32\x18.gcg.AuxiliaryStateValue\"A\n\x13\x41uxiliaryStateValue\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x04\x12\r\n\x05value\x18\x03 \x01(\x0c\"\"\n MergeConfigurationCommitResponse\"|\n\x10\x44riverTaskConfig\x12\x1f\n\x04noop\x18\x01 \x01(\x0b\x32\x0f.gcg.NoopConfigH\x00\x12\x31\n\rstaticContent\x18\x02 \x01(\x0b\x32\x18.gcg.StaticContentConfigH\x00\x42\x14\n\x12\x64river_task_config\"\x0c\n\nNoopConfig\"&\n\x13StaticContentConfig\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"5\n\x1fRetrieveUsedAirlockQuotaRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"P\n RetrieveUsedAirlockQuotaResponse\x12,\n\rairlockQuotas\x18\x01 \x03(\x0b\x32\x15.gcg.AirlockQuotaInfo\"U\n\x10\x41irlockQuotaInfo\x12\x15\n\rairlockNodeId\x18\x01 \x01(\t\x12\x12\n\nquotaBytes\x18\x02 \x01(\x04\x12\x16\n\x0eusedQuotaBytes\x18\x03 \x01(\x04\"+\n\x16GetResultsSizeResponse\x12\x11\n\tsizeBytes\x18\x01 \x01(\x04\"\x85\x01\n\x0cGcgRequestV2\x12\x36\n\x0funauthenticated\x18\x01 \x01(\x0b\x32\x1b.gcg.UnauthenticatedRequestH\x00\x12\x32\n\rauthenticated\x18\x02 \x01(\x0b\x32\x19.gcg.AuthenticatedRequestH\x00\x42\t\n\x07request\"\xe0\x04\n\x14\x41uthenticatedRequest\x12\x15\n\x0b\x61\x63\x63\x65ssToken\x18\x01 \x01(\tH\x00\x12\x12\n\x08\x61piToken\x18\x02 \x01(\tH\x00\x12\x30\n\x0c\x63reatePolicy\x18\x03 \x01(\x0b\x32\x18.gcg.CreatePolicyRequestH\x01\x12;\n\x0bsecretStore\x18\x04 \x01(\x0b\x32$.secret_store_api.SecretStoreRequestH\x01\x12<\n\x12getVerificationKey\x18\x06 \x01(\x0b\x32\x1e.gcg.GetVerificationKeyRequestH\x01\x12*\n\tdcrAction\x18\x07 \x01(\x0b\x32\x15.gcg.DcrActionRequestH\x01\x12\x34\n\x0e\x63reateApiToken\x18\x08 \x01(\x0b\x32\x1a.gcg.CreateApiTokenRequestH\x01\x12\x30\n\x0cgetApiTokens\x18\t \x01(\x0b\x32\x18.gcg.GetApiTokensRequestH\x01\x12\x34\n\x0e\x64\x65leteApiToken\x18\n \x01(\x0b\x32\x1a.gcg.DeleteApiTokenRequestH\x01\x12N\n\x1bretrieveResultEncryptionKey\x18\x0b \x01(\x0b\x32\'.gcg.RetrieveResultEncryptionKeyRequestH\x01\x12\x42\n\x15\x65xportResultAsDataset\x18\x0c \x01(\x0b\x32!.gcg.ExportResultAsDatasetRequestH\x01\x42\x07\n\x05tokenB\t\n\x07request\"\xb7\x04\n\x15\x41uthenticatedResponse\x12\x31\n\x0c\x63reatePolicy\x18\x03 \x01(\x0b\x32\x19.gcg.CreatePolicyResponseH\x00\x12<\n\x0bsecretStore\x18\x04 \x01(\x0b\x32%.secret_store_api.SecretStoreResponseH\x00\x12=\n\x12getVerificationKey\x18\x06 \x01(\x0b\x32\x1f.gcg.GetVerificationKeyResponseH\x00\x12+\n\tdcrAction\x18\x07 \x01(\x0b\x32\x16.gcg.DcrActionResponseH\x00\x12\x35\n\x0e\x63reateApiToken\x18\x08 \x01(\x0b\x32\x1b.gcg.CreateApiTokenResponseH\x00\x12\x31\n\x0cgetApiTokens\x18\t \x01(\x0b\x32\x19.gcg.GetApiTokensResponseH\x00\x12\x35\n\x0e\x64\x65leteApiToken\x18\n \x01(\x0b\x32\x1b.gcg.DeleteApiTokenResponseH\x00\x12O\n\x1bretrieveResultEncryptionKey\x18\x0b \x01(\x0b\x32(.gcg.RetrieveResultEncryptionKeyResponseH\x00\x12\x43\n\x15\x65xportResultAsDataset\x18\x0c \x01(\x0b\x32\".gcg.ExportResultAsDatasetResponseH\x00\x42\n\n\x08response\"Y\n\x16UnauthenticatedRequest\x12\x34\n\x0e\x61uthentication\x18\x01 \x01(\x0b\x32\x1a.gcg.AuthenticationRequestH\x00\x42\t\n\x07request\"_\n\rGcgResponseV2\x12/\n\x07success\x18\x01 \x01(\x0b\x32\x1c.gcg.GcgSuccessfulResponseV2H\x00\x12\x11\n\x07\x66\x61ilure\x18\x02 \x01(\tH\x00\x42\n\n\x08response\"\x9c\x01\n\x15\x41uthenticationRequest\x12:\n\nemailStart\x18\x02 \x01(\x0b\x32$.gcg.EmailStartAuthenticationRequestH\x00\x12<\n\x0b\x65mailFinish\x18\x03 \x01(\x0b\x32%.gcg.EmailFinishAuthenticationRequestH\x00\x42\t\n\x07request\"\xa0\x01\n\x16\x41uthenticationResponse\x12;\n\nemailStart\x18\x02 \x01(\x0b\x32%.gcg.EmailStartAuthenticationResponseH\x00\x12=\n\x0b\x65mailFinish\x18\x03 \x01(\x0b\x32&.gcg.EmailFinishAuthenticationResponseH\x00\x42\n\n\x08response\"0\n\x1f\x45mailStartAuthenticationRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"9\n EmailStartAuthenticationResponse\x12\x15\n\rcorrelationId\x18\x01 \x01(\t\"?\n EmailFinishAuthenticationRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\"\x83\x02\n!EmailFinishAuthenticationResponse\x12L\n\rincorrectCode\x18\x01 \x01(\x0b\x32\x33.gcg.EmailFinishAuthenticationResponseIncorrectCodeH\x00\x12\x42\n\x08notFound\x18\x02 \x01(\x0b\x32..gcg.EmailFinishAuthenticationResponseNotFoundH\x00\x12@\n\x07success\x18\x03 \x01(\x0b\x32-.gcg.EmailFinishAuthenticationResponseSuccessH\x00\x42\n\n\x08response\"0\n.EmailFinishAuthenticationResponseIncorrectCode\"+\n)EmailFinishAuthenticationResponseNotFound\"9\n(EmailFinishAuthenticationResponseSuccess\x12\r\n\x05token\x18\x01 \x01(\t\"\x93\x01\n\x17GcgSuccessfulResponseV2\x12\x37\n\x0funauthenticated\x18\x01 \x01(\x0b\x32\x1c.gcg.UnauthenticatedResponseH\x00\x12\x33\n\rauthenticated\x18\x02 \x01(\x0b\x32\x1a.gcg.AuthenticatedResponseH\x00\x42\n\n\x08response\"\\\n\x17UnauthenticatedResponse\x12\x35\n\x0e\x61uthentication\x18\x01 \x01(\x0b\x32\x1b.gcg.AuthenticationResponseH\x00\x42\n\n\x08response\"\x1b\n\x19GetVerificationKeyRequest\"5\n\x1aGetVerificationKeyResponse\x12\x17\n\x0fverificationKey\x18\x01 \x01(\x0c\"f\n\x13\x43reatePolicyRequest\x12\x31\n\x06policy\x18\x01 \x01(\x0b\x32!.release_policy_api.ReleasePolicy\x12\x12\n\x05scope\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x08\n\x06_scope\"(\n\x14\x43reatePolicyResponse\x12\x10\n\x08policyId\x18\x01 \x01(\t\"6\n\x10\x44\x63rActionRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\x0c\"%\n\x11\x44\x63rActionResponse\x12\x10\n\x08response\x18\x01 \x01(\x0c\"%\n\x15\x43reateApiTokenRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\'\n\x16\x43reateApiTokenResponse\x12\r\n\x05token\x18\x01 \x01(\t\"\x15\n\x13GetApiTokensRequest\">\n\x14GetApiTokensResponse\x12&\n\x06tokens\x18\x01 \x03(\x0b\x32\x16.gcg.GetApiTokenResult\"0\n\x11GetApiTokenResult\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"&\n\x15\x44\x65leteApiTokenRequest\x12\r\n\x05token\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteApiTokenResponse\"N\n\"RetrieveResultEncryptionKeyRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x19\n\x11taskResultHashHex\x18\x02 \x01(\t\"U\n#RetrieveResultEncryptionKeyResponse\x12\x17\n\x0fmanifestHashHex\x18\x01 \x01(\t\x12\x15\n\rencryptionKey\x18\x02 \x01(\x0c\"\xb2\x01\n\x1c\x45xportResultAsDatasetRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x19\n\x11taskResultHashHex\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x61tasetName\x18\x03 \x01(\t\x12\x1d\n\x03raw\x18\x04 \x01(\x0b\x32\x0e.gcg.RawExportH\x00\x12\x1d\n\x03zip\x18\x05 \x01(\x0b\x32\x0e.gcg.ZipExportH\x00\x42\x15\n\x13\x65xportSpecification\"\x0b\n\tRawExport\"\x19\n\tZipExport\x12\x0c\n\x04path\x18\x01 \x01(\t\"]\n\x1d\x45xportResultAsDatasetResponse\x12\x17\n\x0fmanifestHashHex\x18\x01 \x01(\t\x12\x11\n\tdatasetId\x18\x02 \x01(\t\x12\x10\n\x08secretId\x18\x03 \x01(\t*)\n\x0e\x44\x61taRoomStatus\x12\n\n\x06\x41\x63tive\x10\x00\x12\x0b\n\x07Stopped\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcg_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EXECUTECOMPUTEREQUEST_PARAMETERSENTRY']._loaded_options = None
  _globals['_EXECUTECOMPUTEREQUEST_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTECOMPUTEREQUEST_TESTDATASETSENTRY']._loaded_options = None
  _globals['_EXECUTECOMPUTEREQUEST_TESTDATASETSENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTEDEVELOPMENTCOMPUTEREQUEST_PARAMETERSENTRY']._loaded_options = None
  _globals['_EXECUTEDEVELOPMENTCOMPUTEREQUEST_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTEDEVELOPMENTCOMPUTEREQUEST_TESTDATASETSENTRY']._loaded_options = None
  _globals['_EXECUTEDEVELOPMENTCOMPUTEREQUEST_TESTDATASETSENTRY']._serialized_options = b'8\001'
  _globals['_MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY']._loaded_options = None
  _globals['_MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY']._serialized_options = b'8\001'
  _globals['_DATAROOMSTATUS']._serialized_start=12506
  _globals['_DATAROOMSTATUS']._serialized_end=12547
  _globals['_GCGREQUEST']._serialized_start=106
  _globals['_GCGREQUEST']._serialized_end=1900
  _globals['_GCGRESPONSE']._serialized_start=1903
  _globals['_GCGRESPONSE']._serialized_end=3723
  _globals['_USERAUTH']._serialized_start=3725
  _globals['_USERAUTH']._serialized_end=3830
  _globals['_PKI']._serialized_start=3832
  _globals['_PKI']._serialized_end=3893
  _globals['_CREATEDATAROOMREQUEST']._serialized_start=3896
  _globals['_CREATEDATAROOMREQUEST']._serialized_end=4076
  _globals['_CREATEDATAROOMRESPONSE']._serialized_start=4079
  _globals['_CREATEDATAROOMRESPONSE']._serialized_end=4219
  _globals['_DATAROOMVALIDATIONERROR']._serialized_start=4222
  _globals['_DATAROOMVALIDATIONERROR']._serialized_end=4548
  _globals['_PUBLISHDATASETTODATAROOMREQUEST']._serialized_start=4551
  _globals['_PUBLISHDATASETTODATAROOMREQUEST']._serialized_end=4679
  _globals['_PUBLISHDATASETTODATAROOMRESPONSE']._serialized_start=4681
  _globals['_PUBLISHDATASETTODATAROOMRESPONSE']._serialized_end=4715
  _globals['_EXECUTECOMPUTEREQUEST']._serialized_start=4718
  _globals['_EXECUTECOMPUTEREQUEST']._serialized_end=5072
  _globals['_EXECUTECOMPUTEREQUEST_PARAMETERSENTRY']._serialized_start=4952
  _globals['_EXECUTECOMPUTEREQUEST_PARAMETERSENTRY']._serialized_end=5001
  _globals['_EXECUTECOMPUTEREQUEST_TESTDATASETSENTRY']._serialized_start=5003
  _globals['_EXECUTECOMPUTEREQUEST_TESTDATASETSENTRY']._serialized_end=5072
  _globals['_EXECUTEDEVELOPMENTCOMPUTEREQUEST']._serialized_start=5075
  _globals['_EXECUTEDEVELOPMENTCOMPUTEREQUEST']._serialized_end=5473
  _globals['_EXECUTEDEVELOPMENTCOMPUTEREQUEST_PARAMETERSENTRY']._serialized_start=4952
  _globals['_EXECUTEDEVELOPMENTCOMPUTEREQUEST_PARAMETERSENTRY']._serialized_end=5001
  _globals['_EXECUTEDEVELOPMENTCOMPUTEREQUEST_TESTDATASETSENTRY']._serialized_start=5003
  _globals['_EXECUTEDEVELOPMENTCOMPUTEREQUEST_TESTDATASETSENTRY']._serialized_end=5072
  _globals['_TESTDATASET']._serialized_start=5475
  _globals['_TESTDATASET']._serialized_end=5533
  _globals['_EXECUTECOMPUTERESPONSE']._serialized_start=5535
  _globals['_EXECUTECOMPUTERESPONSE']._serialized_end=5574
  _globals['_JOBSTATUSREQUEST']._serialized_start=5576
  _globals['_JOBSTATUSREQUEST']._serialized_end=5609
  _globals['_JOBSTATUSRESPONSE']._serialized_start=5611
  _globals['_JOBSTATUSRESPONSE']._serialized_end=5662
  _globals['_GETRESULTSREQUEST']._serialized_start=5664
  _globals['_GETRESULTSREQUEST']._serialized_end=5721
  _globals['_GETRESULTSSIZEREQUEST']._serialized_start=5723
  _globals['_GETRESULTSSIZEREQUEST']._serialized_end=5784
  _globals['_GETRESULTSRESPONSECHUNK']._serialized_start=5786
  _globals['_GETRESULTSRESPONSECHUNK']._serialized_end=5825
  _globals['_GETRESULTSRESPONSEFOOTER']._serialized_start=5827
  _globals['_GETRESULTSRESPONSEFOOTER']._serialized_end=5853
  _globals['_RETRIEVEDATAROOMREQUEST']._serialized_start=5855
  _globals['_RETRIEVEDATAROOMREQUEST']._serialized_end=5900
  _globals['_RETRIEVEDATAROOMRESPONSE']._serialized_start=5903
  _globals['_RETRIEVEDATAROOMRESPONSE']._serialized_end=6083
  _globals['_RETRIEVEAUDITLOGREQUEST']._serialized_start=6085
  _globals['_RETRIEVEAUDITLOGREQUEST']._serialized_end=6130
  _globals['_RETRIEVEAUDITLOGRESPONSE']._serialized_start=6132
  _globals['_RETRIEVEAUDITLOGRESPONSE']._serialized_end=6171
  _globals['_RETRIEVEDATAROOMSTATUSREQUEST']._serialized_start=6173
  _globals['_RETRIEVEDATAROOMSTATUSREQUEST']._serialized_end=6224
  _globals['_RETRIEVEDATAROOMSTATUSRESPONSE']._serialized_start=6226
  _globals['_RETRIEVEDATAROOMSTATUSRESPONSE']._serialized_end=6295
  _globals['_UPDATEDATAROOMSTATUSREQUEST']._serialized_start=6297
  _globals['_UPDATEDATAROOMSTATUSREQUEST']._serialized_end=6383
  _globals['_UPDATEDATAROOMSTATUSRESPONSE']._serialized_start=6385
  _globals['_UPDATEDATAROOMSTATUSRESPONSE']._serialized_end=6415
  _globals['_RETRIEVEPUBLISHEDDATASETSREQUEST']._serialized_start=6417
  _globals['_RETRIEVEPUBLISHEDDATASETSREQUEST']._serialized_end=6471
  _globals['_PUBLISHEDDATASET']._serialized_start=6473
  _globals['_PUBLISHEDDATASET']._serialized_end=6561
  _globals['_RETRIEVEPUBLISHEDDATASETSRESPONSE']._serialized_start=6563
  _globals['_RETRIEVEPUBLISHEDDATASETSRESPONSE']._serialized_end=6648
  _globals['_REMOVEPUBLISHEDDATASETREQUEST']._serialized_start=6650
  _globals['_REMOVEPUBLISHEDDATASETREQUEST']._serialized_end=6717
  _globals['_REMOVEPUBLISHEDDATASETRESPONSE']._serialized_start=6719
  _globals['_REMOVEPUBLISHEDDATASETRESPONSE']._serialized_end=6751
  _globals['_CREATECONFIGURATIONCOMMITREQUEST']._serialized_start=6754
  _globals['_CREATECONFIGURATIONCOMMITREQUEST']._serialized_end=6902
  _globals['_CREATECONFIGURATIONCOMMITRESPONSE']._serialized_start=6904
  _globals['_CREATECONFIGURATIONCOMMITRESPONSE']._serialized_end=6957
  _globals['_GENERATEMERGEAPPROVALSIGNATUREREQUEST']._serialized_start=6959
  _globals['_GENERATEMERGEAPPROVALSIGNATUREREQUEST']._serialized_end=7016
  _globals['_GENERATEMERGEAPPROVALSIGNATURERESPONSE']._serialized_start=7018
  _globals['_GENERATEMERGEAPPROVALSIGNATURERESPONSE']._serialized_end=7077
  _globals['_MERGECONFIGURATIONCOMMITREQUEST']._serialized_start=7080
  _globals['_MERGECONFIGURATIONCOMMITREQUEST']._serialized_end=7368
  _globals['_MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY']._serialized_start=7272
  _globals['_MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY']._serialized_end=7329
  _globals['_RETRIEVECURRENTDATAROOMCONFIGURATIONREQUEST']._serialized_start=7370
  _globals['_RETRIEVECURRENTDATAROOMCONFIGURATIONREQUEST']._serialized_end=7435
  _globals['_RETRIEVECURRENTDATAROOMCONFIGURATIONRESPONSE']._serialized_start=7437
  _globals['_RETRIEVECURRENTDATAROOMCONFIGURATIONRESPONSE']._serialized_end=7553
  _globals['_RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST']._serialized_start=7555
  _globals['_RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST']._serialized_end=7618
  _globals['_RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE']._serialized_start=7620
  _globals['_RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE']._serialized_end=7685
  _globals['_RETRIEVECONFIGURATIONCOMMITREQUEST']._serialized_start=7687
  _globals['_RETRIEVECONFIGURATIONCOMMITREQUEST']._serialized_end=7741
  _globals['_RETRIEVECONFIGURATIONCOMMITRESPONSE']._serialized_start=7744
  _globals['_RETRIEVECONFIGURATIONCOMMITRESPONSE']._serialized_end=7895
  _globals['_CASAUXILIARYSTATEREQUEST']._serialized_start=7897
  _globals['_CASAUXILIARYSTATEREQUEST']._serialized_end=7988
  _globals['_CASAUXILIARYSTATERESPONSE']._serialized_start=7990
  _globals['_CASAUXILIARYSTATERESPONSE']._serialized_end=8079
  _globals['_READAUXILIARYSTATEREQUEST']._serialized_start=8081
  _globals['_READAUXILIARYSTATEREQUEST']._serialized_end=8128
  _globals['_READAUXILIARYSTATERESPONSE']._serialized_start=8130
  _globals['_READAUXILIARYSTATERESPONSE']._serialized_end=8200
  _globals['_AUXILIARYSTATEVALUE']._serialized_start=8202
  _globals['_AUXILIARYSTATEVALUE']._serialized_end=8267
  _globals['_MERGECONFIGURATIONCOMMITRESPONSE']._serialized_start=8269
  _globals['_MERGECONFIGURATIONCOMMITRESPONSE']._serialized_end=8303
  _globals['_DRIVERTASKCONFIG']._serialized_start=8305
  _globals['_DRIVERTASKCONFIG']._serialized_end=8429
  _globals['_NOOPCONFIG']._serialized_start=8431
  _globals['_NOOPCONFIG']._serialized_end=8443
  _globals['_STATICCONTENTCONFIG']._serialized_start=8445
  _globals['_STATICCONTENTCONFIG']._serialized_end=8483
  _globals['_RETRIEVEUSEDAIRLOCKQUOTAREQUEST']._serialized_start=8485
  _globals['_RETRIEVEUSEDAIRLOCKQUOTAREQUEST']._serialized_end=8538
  _globals['_RETRIEVEUSEDAIRLOCKQUOTARESPONSE']._serialized_start=8540
  _globals['_RETRIEVEUSEDAIRLOCKQUOTARESPONSE']._serialized_end=8620
  _globals['_AIRLOCKQUOTAINFO']._serialized_start=8622
  _globals['_AIRLOCKQUOTAINFO']._serialized_end=8707
  _globals['_GETRESULTSSIZERESPONSE']._serialized_start=8709
  _globals['_GETRESULTSSIZERESPONSE']._serialized_end=8752
  _globals['_GCGREQUESTV2']._serialized_start=8755
  _globals['_GCGREQUESTV2']._serialized_end=8888
  _globals['_AUTHENTICATEDREQUEST']._serialized_start=8891
  _globals['_AUTHENTICATEDREQUEST']._serialized_end=9499
  _globals['_AUTHENTICATEDRESPONSE']._serialized_start=9502
  _globals['_AUTHENTICATEDRESPONSE']._serialized_end=10069
  _globals['_UNAUTHENTICATEDREQUEST']._serialized_start=10071
  _globals['_UNAUTHENTICATEDREQUEST']._serialized_end=10160
  _globals['_GCGRESPONSEV2']._serialized_start=10162
  _globals['_GCGRESPONSEV2']._serialized_end=10257
  _globals['_AUTHENTICATIONREQUEST']._serialized_start=10260
  _globals['_AUTHENTICATIONREQUEST']._serialized_end=10416
  _globals['_AUTHENTICATIONRESPONSE']._serialized_start=10419
  _globals['_AUTHENTICATIONRESPONSE']._serialized_end=10579
  _globals['_EMAILSTARTAUTHENTICATIONREQUEST']._serialized_start=10581
  _globals['_EMAILSTARTAUTHENTICATIONREQUEST']._serialized_end=10629
  _globals['_EMAILSTARTAUTHENTICATIONRESPONSE']._serialized_start=10631
  _globals['_EMAILSTARTAUTHENTICATIONRESPONSE']._serialized_end=10688
  _globals['_EMAILFINISHAUTHENTICATIONREQUEST']._serialized_start=10690
  _globals['_EMAILFINISHAUTHENTICATIONREQUEST']._serialized_end=10753
  _globals['_EMAILFINISHAUTHENTICATIONRESPONSE']._serialized_start=10756
  _globals['_EMAILFINISHAUTHENTICATIONRESPONSE']._serialized_end=11015
  _globals['_EMAILFINISHAUTHENTICATIONRESPONSEINCORRECTCODE']._serialized_start=11017
  _globals['_EMAILFINISHAUTHENTICATIONRESPONSEINCORRECTCODE']._serialized_end=11065
  _globals['_EMAILFINISHAUTHENTICATIONRESPONSENOTFOUND']._serialized_start=11067
  _globals['_EMAILFINISHAUTHENTICATIONRESPONSENOTFOUND']._serialized_end=11110
  _globals['_EMAILFINISHAUTHENTICATIONRESPONSESUCCESS']._serialized_start=11112
  _globals['_EMAILFINISHAUTHENTICATIONRESPONSESUCCESS']._serialized_end=11169
  _globals['_GCGSUCCESSFULRESPONSEV2']._serialized_start=11172
  _globals['_GCGSUCCESSFULRESPONSEV2']._serialized_end=11319
  _globals['_UNAUTHENTICATEDRESPONSE']._serialized_start=11321
  _globals['_UNAUTHENTICATEDRESPONSE']._serialized_end=11413
  _globals['_GETVERIFICATIONKEYREQUEST']._serialized_start=11415
  _globals['_GETVERIFICATIONKEYREQUEST']._serialized_end=11442
  _globals['_GETVERIFICATIONKEYRESPONSE']._serialized_start=11444
  _globals['_GETVERIFICATIONKEYRESPONSE']._serialized_end=11497
  _globals['_CREATEPOLICYREQUEST']._serialized_start=11499
  _globals['_CREATEPOLICYREQUEST']._serialized_end=11601
  _globals['_CREATEPOLICYRESPONSE']._serialized_start=11603
  _globals['_CREATEPOLICYRESPONSE']._serialized_end=11643
  _globals['_DCRACTIONREQUEST']._serialized_start=11645
  _globals['_DCRACTIONREQUEST']._serialized_end=11699
  _globals['_DCRACTIONRESPONSE']._serialized_start=11701
  _globals['_DCRACTIONRESPONSE']._serialized_end=11738
  _globals['_CREATEAPITOKENREQUEST']._serialized_start=11740
  _globals['_CREATEAPITOKENREQUEST']._serialized_end=11777
  _globals['_CREATEAPITOKENRESPONSE']._serialized_start=11779
  _globals['_CREATEAPITOKENRESPONSE']._serialized_end=11818
  _globals['_GETAPITOKENSREQUEST']._serialized_start=11820
  _globals['_GETAPITOKENSREQUEST']._serialized_end=11841
  _globals['_GETAPITOKENSRESPONSE']._serialized_start=11843
  _globals['_GETAPITOKENSRESPONSE']._serialized_end=11905
  _globals['_GETAPITOKENRESULT']._serialized_start=11907
  _globals['_GETAPITOKENRESULT']._serialized_end=11955
  _globals['_DELETEAPITOKENREQUEST']._serialized_start=11957
  _globals['_DELETEAPITOKENREQUEST']._serialized_end=11995
  _globals['_DELETEAPITOKENRESPONSE']._serialized_start=11997
  _globals['_DELETEAPITOKENRESPONSE']._serialized_end=12021
  _globals['_RETRIEVERESULTENCRYPTIONKEYREQUEST']._serialized_start=12023
  _globals['_RETRIEVERESULTENCRYPTIONKEYREQUEST']._serialized_end=12101
  _globals['_RETRIEVERESULTENCRYPTIONKEYRESPONSE']._serialized_start=12103
  _globals['_RETRIEVERESULTENCRYPTIONKEYRESPONSE']._serialized_end=12188
  _globals['_EXPORTRESULTASDATASETREQUEST']._serialized_start=12191
  _globals['_EXPORTRESULTASDATASETREQUEST']._serialized_end=12369
  _globals['_RAWEXPORT']._serialized_start=12371
  _globals['_RAWEXPORT']._serialized_end=12382
  _globals['_ZIPEXPORT']._serialized_start=12384
  _globals['_ZIPEXPORT']._serialized_end=12409
  _globals['_EXPORTRESULTASDATASETRESPONSE']._serialized_start=12411
  _globals['_EXPORTRESULTASDATASETRESPONSE']._serialized_end=12504
# @@protoc_insertion_point(module_scope)



from enum import Enum
from typing import Any, Dict, List, Optional, Union
from typing_extensions import Self
from .api import SeedAudience, CustomAudience
from .audiences import AudienceType
from .participant import Participant


class FilterOperator(str, Enum):
    """
    Enum representing the filter operations.

    Members:
        - CONTAINS_ANY: At least one of the values must be present.
        - CONTAINS_NONE: None of the values can be present.
        - CONTAINS_ALL: All of the values must be present.
        - EMPTY: The attribute must be empty.
        - NOT_EMPTY: The attribute must not be empty.
    """
    CONTAINS_ANY = "CONTAINS_ANY_OF"
    CONTAINS_NONE = "CONTAINS_NONE_OF"
    CONTAINS_ALL = "CONTAINS_ALL_OF"
    EMPTY = "EMPTY"
    NOT_EMPTY = "NOT_EMPTY"


class Filter:
    """
    Class representing a filter.
    """
    def __init__(
        self, *, attribute: str, values: List[str], operator: FilterOperator
    ) -> None:
        """
        Initialize a filter.

        **Parameters**:
        - `attribute`: The attribute to filter on
        - `values`: The values to filter on
        - `operator`: The operator to use for the filter
        """
        self.attribute = attribute
        self.values = values
        self.operator = operator

    def as_dict(self) -> Dict[str, Any]:
        """
        Convert the filter to a dictionary.

        **Returns**:
        - The dictionary representation of the filter
        """
        return {
            "operator": self.operator.value,
            "attribute": self.attribute,
            "values": self.values,
        }


class MatchOperator(str, Enum):
    """
    Enum representing the match operations.

    Members:
        - MATCH_ALL: All filter criteria must be satisfied.
        - MATCH_ANY: Any filter criteria may be satisfied.
    """
    # All filter criteria must be satisfied.
    MATCH_ALL = "AND"
    # Any filter criteria may be satisfied.
    MATCH_ANY = "OR"


class AudienceFilters:
    """
    Class representing the filters for an audience.
    """
    def __init__(
        self,
        *,
        filters: List[Filter],
        operator: MatchOperator,
    ) -> None:
        """
        Initialize an AudienceFilters instance.

        **Parameters**:
        - `filters`: The list of filters to apply
        - `operator`: The operator to use for the filters
        """
        self.filters = filters
        self.operator = operator

    def as_dict(self) -> Dict[str, Any]:
        """
        Convert the filters to a dictionary.

        **Returns**:
        - The dictionary representation of the filters
        """
        return {
            "booleanOp": self.operator.value,
            "filters": [f.as_dict() for f in self.filters],
        }


class CombineOperator(str, Enum):
    """
    Enum representing the operations for combining audiences.

    Members:
        - INTERSECT: Users in both audiences.
        - UNION: All users.
        - DIFF: Users in first audience only.
    """
    # Users in both audiences.
    INTERSECT = "INTERSECT"
    # All users.
    UNION = "UNION"
    # Users in first audience only.
    DIFF = "DIFF"


class AudienceCombinator:
    def __init__(
        self,
        *,
        operator: CombineOperator,
        source_audience: AudienceType,
        filters: Optional[AudienceFilters] = None,
    ) -> None:
        """
        Initialize an AudienceCombinator instance.

        **Parameters**:
        - `operator`: The operator used to combine audiences
        - `source_audience`: The source audience to combine
        - `filters`: Optional filters to apply to the source audience
        """
        self.operator = operator
        self.source_audience = source_audience
        self.filters = filters

    def as_dict(self) -> Dict[str, Any]:
        """
        Convert the audience combinator to a dictionary.

        **Returns**:
        - The dictionary representation of the audience combinator
        """
        return {
            "operator": self.operator.value,
            "sourceRef": self.source_audience.model_dump(mode="json"),
            "filters": self.filters.as_dict() if self.filters else None,
        }


class RuleBasedAudienceDefinition:
    """
    Class representing the definition of a rule-based audience.
    """

    def __init__(
        self,
        *,
        name: str,
        source_audience: AudienceType,
        filters: Optional[AudienceFilters] = None,
        combinators: Optional[List[AudienceCombinator]] = None,
        shared_with: Optional[List[Participant]] = None,
    ) -> None:
        """
        Initialize a rule-based audience definition.

        **Parameters**:
        - `name`: Name of the rule-based audience
        - `source_audience`: The source audience to build from
        - `filters`: Optional filters to apply to the audience
        - `combinators`: Optional combinators for combining multiple audiences
        - `shared_with`: Optional list of participant groups to share with
        """
        self.name = name
        self.source_audience = source_audience
        self.filters = filters
        self.combinators = combinators
        self.kind = "RULE_BASED"
        self.shared_with = [participant.id for participant in shared_with]

class RuleBasedAudienceBuilder:
    """
    Builder for constructing rule-based audience definitions.
    """

    def __init__(
        self,
        *,
        name: str,
        source_audience: AudienceType,
    ) -> None:
        """
        Initialise the rule-based audience builder.

        **Parameters**:
        - `name`: Name of the rule-based audience.
        - `source_audience`: The source audience that the rule-based audience will be built from.
        """
        self.name = name
        self.source_audience = source_audience
        self.filters = None
        self.combinators = None
        self.shared_with = []

    def with_share_with_participants(self, participants: List[Participant]) -> Self:
        """
        Make the rule-based audience available to the given participants.

        **Parameters**:
        - `participants`: The participants to share the rule-based audience with

        **Returns**:
        - The updated rule-based audience builder
        """
        self.shared_with = participants
        return self

    def with_filters(self, filters: AudienceFilters) -> Self:
        """
        Set the filters to be applied to the source audience.

        **Parameters**:
        - `filters`: Filters to be applied to the source audience.

        **Returns**:
        - The updated rule-based audience builder
        """
        self.filters = filters
        return self

    def with_combinator(self, combinators: List[AudienceCombinator]) -> Self:
        """
        Set the combinators to be applied to the audiences.
        This defines how multiple audiences can be combined.

        **Parameters**:
        - `combinators`: The list of combinators used to combine audiences.

        **Returns**:
        - The updated rule-based audience builder
        """
        self.combinators = combinators
        return self

    def build(self) -> RuleBasedAudienceDefinition:
        """
        Build the rule-based audience definition.

        **Returns**:
        - The rule-based audience definition
        """
        return RuleBasedAudienceDefinition(
            name=self.name,
            source_audience=self.source_audience,
            filters=self.filters,
            combinators=self.combinators,
            shared_with=self.shared_with,
        )


class AudienceCombinatorBuilder:
    """
    Builder for constructing an `AudienceCombinator`.
    """

    def __init__(
        self,
        *,
        operator: CombineOperator,
        source_audience: Union[SeedAudience, CustomAudience],
    ) -> None:
        """
        Initialise the audience combinator builder.

        **Parameters**:
        - `operator`: The operator used to combine audiences.
        - `source_audience`: The source audience to combine with.
        """
        self.operator = operator
        self.source_audience = source_audience
        self.filters = None

    def with_filters(self, filters: AudienceFilters) -> Self:
        """
        Set the filters to be applied to the source audience.

        **Parameters**:
        - `filters`: Filters to be applied to the source audience.

        **Returns**:
        - The updated audience combinator builder
        """
        self.filters = filters
        return self

    def build(self) -> AudienceCombinator:
        """
        Build the audience combinator.

        **Returns**:
        - The audience combinator
        """
        return AudienceCombinator(
            operator=self.operator,
            source_audience=self.source_audience,
            filters=self.filters,
        )



import csv
import io
import zipfile
from typing import Any, List, Optional, Tuple, TYPE_CHECKING

from ...client import SecretStoreOptions
from ...proto import AuthenticationMethod, Permission
from ...proto.length_delimited import parse_length_delimited
from ...session import Session
from ...storage import Key
from ..builders import DataRoomBuilder
from ..compute import Noop
from ..permission import Permissions
from .compute import SqlSchemaVerifier
from .proto import TableSchema

def _data_node_id(node: str):
    return f"{node}_leaf"


def _verifier_node_id(node: str):
    return f"{node}_verification"


class TabularDataNodeBuilder:
    """
    Helper class to construct the triplet of nodes consisting of a data node to
    store tabular input data, as well as a schema validation computation.

    In a data clean room computations and the data they depend on are expressed in terms
    of graphs where computations are represented by *compute nodes* and input datasets are
    represented by *data nodes*.
    With tabular input data, it is possible to validate the input data and check whether it
    corresponds to a pre-defined schema. This validation is a computation in itself so in
    order to validate the input data, we need to add an additional compute node on top of the

    This class will add the necessary nodes to your data clean room.

    After having constructed an object of this class, call its `add_to_builder` method
    and pass it a `DataRoomBuilder` instance. This will add the necessary nodes and required
    user permissions to the builder instance.

    Data should be published to the node with id `input_node_id` and be read from `output_node_id`.

    This class uses a special convention for the ids of the nodes added to the data room based on
    the table name given to the builder. Assuming you use `"my_table"` as the `table_name` when
    instantiating the `TabularDataNodeBuilder`, then the following three nodes will be added:

    1. `my_table_leaf` - the data node to which you can upload data.
    2. `my_table_verification` - the id of the compute node that verifies the schema of the data.
        Subsequent SQL compute nodes should read data from this node.

    The helper function `upload_and_publish_tabular_dataset` will upload, publish, and validate your
    data automatically, without you having to worry about internal naming.
    """

    def __init__(
        self,
        table_name: str,
        schema: List[Tuple[str, Any, bool]],
        *,
        is_required: bool = False,
    ):
        """
        Create a `TabularDataNodeBuilder`.

        **Parameters**:
        - `table_name`: What your dataset should be called. This is the name you will later use in
            your SQL queries.
        - `schema`: The list of columns. This is a list of tuples, each containing the name of the column,
            the data type (`decentriq_platform.sql.proto.PrimitiveType`), and whether the column is nullable (can have empty values).
            The data type is an enum like object with values `PrimitiveType.STRING`, `PrimitiveType.INT64`,
            `PrimitiveType.FLOAT64`.
        - `is_required`: Whether the dataset needs to be present for computations to be triggered.
        """
        self.table_name = table_name
        self.is_required = is_required
        self._leaf_node_id = _data_node_id(table_name)
        self._verifier_node_id = _verifier_node_id(table_name)

        self._verifier = SqlSchemaVerifier(
            self._verifier_node_id,
            input_data_node=self._leaf_node_id,
            columns=schema,
        )

    def add_to_builder(
        self,
        builder: DataRoomBuilder,
        authentication: AuthenticationMethod,
        users: List[str],
    ) -> Tuple[str, str]:
        """
        Configure the given `DataRoomBuilder` to build the final data clean room with the
        necessary compute and data nodes.
        This call will also add the necessary permissions to the data room
        builder that let each user in the list of users perform the following
        tasks:

        1. Upload data to the data node.
        2. Use the data in downstream computations while making sure
           the schema is valid.
        3. Trigger the schema validation step separately as its own computation.

        **Parameters**:
        - `builder`: The builder object to which to add the data and compute as well as
            the permissions.
        - `authentication`: The authentication method used to authenticate the users
            from within the enclave.
        - `users`: A list of email addresses that will be given permissions both for
            the validation of the data as well as the uploading of data.

        **Returns**:
        A tuple containing, as the first element, the id of the data node, and,
        as a second element, the id of the verification computation.
        The data node id must be used when publishing data to the data node.
        The id of the verification computation must be used when depending on
        this dataset from downstream computations (e.g. SQL queries).
        """
        builder.add_data_node(
            self._leaf_node_id, is_required=self.is_required, node_id=self._leaf_node_id
        )
        builder.add_compute_node(self._verifier, node_id=self._verifier_node_id)
        for email in users:
            builder.add_user_permission(
                email=email,
                authentication_method=authentication,
                permissions=[
                    self.validation_permission,
                    self.result_permission,
                    self.leaf_crud_permission,
                ],
            )
        return (self._leaf_node_id, self._verifier_node_id)

    @property
    def validation_permission(self) -> Permission:
        """The permission required to trigger the data validation."""
        return Permissions.execute_compute(self._verifier_node_id)

    @property
    def result_permission(self) -> Permission:
        """The permission required to trigger the data validation."""
        return Permissions.retrieve_compute_result(self._verifier_node_id)

    @property
    def leaf_crud_permission(self) -> Permission:
        """The permission required to upload the raw, non-validated data."""
        return Permissions.leaf_crud(self._leaf_node_id)

    @property
    def input_node_id(self) -> str:
        """The node id to which data should be uploaded."""
        return self._leaf_node_id

    @property
    def output_node_id(self) -> str:
        """
        The id of the node from which the validated data can be read.
        This id needs to be specified in the list of dependencies of any
        downstream computations (such as SQL queries).
        """
        return self._verifier_node_id


def read_input_csv_file(
    path: str,
    /,
    *,
    has_header: bool = True,
    check_header: bool = True,
    encoding="utf-8",
    **kwargs,
) -> io.BytesIO:
    """
    Read CSV from a file and turn it into a bytes array of the correct format so that it can be uploaded
    to the Decentriq platform.

    **Parameters**:
    - `path`: The path to the CSV file.
    - `has_header`: Whether the string contains a header row.
    - `check_header`: Whether the function should try to determine whether the file has a header.
        If the file has a header row but you didn't set the `has_header` flag, an
        exception will be raised. If you're sure that the way you use the function
        is correct, you can disable this check using this parameter.
    - `encoding`: The encoding of the CSV file. If you wrote the CSV file using a library like pandas,
        you need to check the documentation to see what encoding they use by default
        when writing files (likely `"utf-8"` in which case this can be left at its default value).
    - `delimiter`: What delimiter is used in the the CSV file. Default is the comma.
    - `**kwargs`: Additional keyword arguments passed to the Python CSV parser. Refer to the
        [official documentation](https://docs.python.org/3/library/csv.html#csv-fmt-params)
        for a list of supported arguments.

    **Returns**:
    A BytesIO object that can be passed to the methods resposible for uploading data.
    """
    with open(path, "r", encoding=encoding) as csvfile:
        return _read_input_csv(
            csvfile,
            has_header=has_header,
            check_header=check_header,
            **kwargs,
        )


def read_input_csv_string(
    content: str, /, *, has_header: bool = True, check_header: bool = True, **kwargs
) -> io.BytesIO:
    """
    Read CSV from a string and turn it into a bytes array of the correct format so that it can be uploaded
    to the Decentriq platform.

    **Parameters**:
    - `content`: The string containing the CSV file.
    - `has_header`: Whether the string contains a header row.
    - `check_header`: Whether the function should try to determine whether the file has a header.
        If the file has a header row but you didn't set the `has_header` flag, an
        exception will be raised. If you're sure that the way you use the function
        is correct, you can disable this check using this parameter.
    - `encoding`: The encoding of the source file. If you wrote the CSV file using a library like pandas,
        you need to check the documentation to see what encoding they use by default
        when writing files.
    - `delimiter`: What delimiter is used in the the CSV file. Default is the comma.
    - `**kwargs`: Additional keyword arguments passed to the Python CSV parser. What flags can be passed can be
        seen [here](https://docs.python.org/3/library/csv.html#csv-fmt-params).

    **Returns**:
    A BytesIO object that can be passed to the methods resposible for uploading data.
    """
    return _read_input_csv(
        io.StringIO(content.strip()),
        has_header=has_header,
        check_header=check_header,
        **kwargs,
    )


def _read_input_csv(
    data: io.TextIOBase,
    /,
    *,
    has_header: bool = True,
    check_header: bool = True,
    **kwargs,
) -> io.BytesIO:
    if check_header:
        sample = "\n".join(data.readline() for _ in range(20))
        file_has_header = csv.Sniffer().has_header(sample)
        if file_has_header and has_header is False:
            raise Exception(
                "Warning: the file seems to have a header but the header flag is not set to true!"
                " This flag needs to be set correctly in order for the data to be uploaded."
            )
        elif not file_has_header and has_header is True:
            raise Exception(
                "Warning: the file doesn't seem to have a header but the header flag is set!"
                " This flag needs to be set correctly in order for the data to be uploaded."
            )
        data.seek(0)
    reader = csv.reader(data, **kwargs)
    output = io.StringIO(newline="")
    writer = csv.writer(
        output, delimiter=",", quotechar='"', quoting=csv.QUOTE_MINIMAL, dialect="unix"
    )
    if has_header:
        next(reader)
    # This will write the full file into memory and encode it in bulk.
    # Could be wrapped in a IO buffer-style class that would perform the
    # read/write csv lines operation in a streaming fashion.
    for row in reader:
        writer.writerow(row)
    output.seek(0)
    return io.BytesIO(output.read().encode("utf-8"))


def upload_and_publish_tabular_dataset(
    data: io.BytesIO,
    key: Key,
    data_room_id: str,
    *,
    table: str,
    session: Session,
    description: str = "",
    validate: bool = True,
    secret_store_options: Optional[SecretStoreOptions] = None,
    **kwargs,
) -> str:
    """
    Convenience function for uploading data and validating the schema of the uploaded
    data.

    Validation of tabular data is a separate computation for which specific compute nodes
    need to be present in the compute graph defined by the data room definition.
    This function will take care of triggering the validation action for you.
    In case validation fails, an exception will be raised. Validation can be turned off
    using the `validate` parameter.

    **Parameters**:
    - `data`: The input data to be uploaded. Use one of the reader functions provided in this
        package to read CSV-like data.
    - `key`: A key for encrypting the data to-be-uploaded.
    - `data_room_id`: To which data room the dataset should be published. This is the id you
        get when publishing a data room.
    - `table`: The name of the data node builder.
    - `session`: The session with which to communicate with the enclave.
    - `description`: An optional description of the dataset.
    - `validate`: Whether to perform the validation operation.

    **Returns**:
    The manifest hash (dataset id) in case the upload and validation succeeded.
    """
    manifest_hash = session.client.upload_dataset(
        data, key, table, description=description, secret_store_options=secret_store_options
    )
    session.publish_dataset(
        data_room_id, manifest_hash, leaf_id=_data_node_id(table), key=key
    )

    if validate:
        try:
            job_id = session.run_computation(data_room_id, _verifier_node_id(table))
            session.wait_until_computation_has_finished(job_id, **kwargs)
        except Exception as e:
            raise Exception("Validation of dataset failed! Reason: {}".format(e))

    return manifest_hash


def _read_sql_query_result(result: bytes) -> Tuple[str, TableSchema]:
    archive = zipfile.ZipFile(io.BytesIO(result), "r")

    if not {"dataset.csv", "types"}.issubset(archive.namelist()):
        raise Exception(
            "The given result cannot be read as it doesn't contain all the required files."
            " Expected files: 'dataset.csv' and 'types', only found: [{}]".format(
                ", ".join(archive.namelist())
            )
        )

    csv = archive.read("dataset.csv").decode()
    schema = TableSchema()
    parse_length_delimited(archive.read("types"), schema)

    return (csv, schema)


def read_sql_query_result_as_list(result: bytes) -> Tuple[List[List[str]], TableSchema]:
    """
    Read the given raw CSV output from an SQL query result and transform it into a list of
    lists, where each inner list corresponds to a row in the tabular output data.
    The header row won't be contained in the resulting output and all the inner values
    will be of type string.
    The actual column types as well as their names will be returned as part of the schema
    value.
    """
    csv_content, schema = _read_sql_query_result(result)
    reader = csv.reader(io.StringIO(csv_content))
    return list(reader), schema


def read_sql_query_result_as_string(result: bytes, include_header: bool = True) -> str:
    """
    Read the given raw CSV output from an SQL query result and transform it into a string
    containing the full CSV file including the header row.
    The resulting string can be written directly to a file from where it can be read
    using your data analysis library of choice.

    **Parameters**:
    - `result`: The result from which to extract a CSV file as a string.
    - `include_header`: Whether to include an additional header row that contains
        column names (provided for example by using alias expressions
        in SELECT statements). If this setting is true, but no column
        names could be found, the names "V1", "V2" and so will be used.
    """
    content, schema = _read_sql_query_result(result)

    if include_header:
        opt_columns = [col.name for col in schema.namedColumns]
        # Use V1, V2, ... for unknown column names => same format as R uses.
        replacement_columns = [f"V{ix}" for ix in range(1, len(opt_columns) + 1)]
        columns = [c1 if c1 else c2 for c1, c2 in zip(opt_columns, replacement_columns)]
        returned_content = ",".join(columns) + "\n" + content
    else:
        returned_content = content

    # Remove trailing newlines
    return returned_content.strip()



from typing import Literal, Optional

from google.protobuf.json_format import MessageToDict

from decentriq_platform.legacy.data_source_s3.proto.data_source_s3_pb2 import S3Provider

from ...proto import (
    ComputeNodeFormat,
    parse_length_delimited,
    serialize_length_delimited,
)
from ..node import Node
from .proto import DataSourceS3WorkerConfiguration, S3Source

__docformat__ = "restructuredtext"
__pdoc__ = {
    "proto": False,
}


class DataSourceS3(Node):
    """
    Compute node that fetches a dataset from an S3 bucket.
    """

    def __init__(
        self,
        name: str,
        bucket: str,
        object_key: str,
        credentials_dependency: str,
        s3_provider: Literal["AWS", "GCS"],
        region: str = "",
    ) -> None:
        """
        Create a S3 source node.

        **Parameters**:
        - `name`: A human-readable identifier of the node.
        - `bucket`: The name of the AWS bucket within which the source
            file is located.
        - `region`: The region identifier, e.g. "eu-west-3".
        - `object_key`: The path to the file within the specified bucket,
            e.g. "my/directory/my_file.csv" (notice the lack of a leading slash).
        - `credentials_dependency`: The id of the node that serves the credentials
            for connecting to AWS.
            This node should provide a single JSON with format:
            - For AWS:
            ```
            {
                "accessKey": "xxxx",
                "secretKey": "yyyy"
            }
            - For GCS, see [service account credentials](https://cloud.google.com/iam/docs/service-account-creds)
            ```

            In most cases this node will be a simple data node to which the
            credentials JSON payload is published. Note that the credentials will
            always be encrypted end-to-end and won't be readable by anyone, including
            Decentriq. If using this node for a one-off import of a dataset,
            the credentials file can be deleted after the import has finished.
        - `s3_provider`: A Literal indicating the cloud provider for the S3 storage.

            Supported providers are Amazon Web Services S3 buckets (`"AWS"`) and Google Cloud Storage buckets (`"GCS"`).
        """
        if s3_provider == "AWS":
            s3Provider = S3Provider.AWS
        elif s3_provider == "GCS":
            s3Provider = S3Provider.GCS
        else:
            raise Exception(f"Unsupported S3 provider: {s3_provider}")

        config = DataSourceS3WorkerConfiguration(
            source=S3Source(
                bucket=bucket,
                region=region,
                objectKey=object_key,
            ),
            credentialsDependency=credentials_dependency,
            s3Provider=s3Provider,
        )
        config_serialized = serialize_length_delimited(config)
        super().__init__(
            name,
            config=config_serialized,
            enclave_type="decentriq.data-source-s3-worker",
            dependencies=[credentials_dependency],
            output_format=ComputeNodeFormat.RAW,
        )


from ...decoder import DataSourceS3WorkerDecoder

__all__ = [
    "DataSourceS3",
]



from __future__ import annotations

from dataclasses import dataclass
import io
import json
from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
import zipfile

from decentriq_dcr_compiler.schemas import (
    DatasetSinkComputationNode,
    DatasetSinkInput,
)
from decentriq_dcr_compiler.schemas.secret_store_entry_state import (
    SecretStoreEntryState,
)
from typing_extensions import Self

from ..storage import Key

from ..session import Session
from ..archv2 import Secret
from .high_level_node import ComputationNode
from .node_definitions import NodeDefinition

if TYPE_CHECKING:
    from ..client import Client


class SinkInput:
    def __init__(self, high_level: Dict[str, Any]) -> None:
        self.high_level_definition = high_level


class SinkInputFormat:
    """
    Factory for creating the desired `SinkInput` type.
    """

    @staticmethod
    def raw() -> SinkInput:
        """
        Store a single raw file to the Decentriq Platform.
        """
        return SinkInput({"raw": ()})

    @staticmethod
    def all() -> SinkInput:
        """
        Store all files in a zip to the Decentriq Platform.
        """
        return SinkInput({"zip": {"all": ()}})

    @staticmethod
    def files(files: List[str]) -> SinkInput:
        """
        Store the specified files in a zip to the Decentriq Platform.
        """
        return SinkInput({"zip": {"files": files}})


class DatasetSinkComputeNodeDefinition(NodeDefinition):
    def __init__(
        self,
        name: str,
        dataset_name: str,
        dependency: str,
        encryption_key_dependency: str,
        input_type: SinkInput,
        is_key_hex_encoded: Optional[bool] = False,
        id: Optional[str] = None,
    ) -> None:
        """
        Initialise a `DatasetSinkComputeNodeDefinition`.
        This class is used to construct DatasetSinkComputeNodes.

        **Parameters**:
        - `name`: Name of the `DatasetSinkComputeNodeDefinition`.
        - `dataset_name`: Name of the dataset when it is stored in the Decentriq Platform.
        - `dependency`: Name of the node whose data will be stored.
        - `encryption_key_dependency`: Name of the node storing the encryption key that
                will be used to encrypt the dataset in the Decentriq Platform.
        - `input_type`: The type of input data to be stored (raw, list of files in a zip, entire zip contents).
        - `is_key_hex_encoded`: Flag indicating whether or not the encryption key is hex encoded (`False` indicates raw bytes).
        - `id`: Optional ID of the dataset sink node.
        """
        super().__init__(name, id=id or name)
        self.dataset_name = dataset_name
        self.dependency = dependency
        self.encryption_key_dependency = encryption_key_dependency
        self.is_key_hex_encoded = is_key_hex_encoded
        self.input_type = input_type
        self.specification_id = "decentriq.dataset-sink-worker"

    def _get_high_level_representation(self) -> Dict[str, str]:
        """
        Retrieve the high level representation of the `DatasetSinkComputeNodeDefinition`.
        """
        computation_node = {
            "id": self.id,
            "name": self.name,
            "kind": {
                "computation": {
                    "kind": {
                        "datasetSink": {
                            "datasetImportId": None,
                            "encryptionKeyDependency": {
                                "dependency": self.encryption_key_dependency,
                                "isKeyHexEncoded": self.is_key_hex_encoded,
                            },
                            "input": {
                                "datasetName": self.dataset_name,
                                "dependency": self.dependency,
                                "inputDataType": self.input_type.high_level_definition,
                            },
                            "specificationId": self.specification_id,
                        }
                    }
                },
            },
        }
        return computation_node

    @property
    def required_workers(self):
        return [self.specification_id]

    @classmethod
    def _from_high_level(
        cls,
        id: str,
        name: str,
        node: DatasetSinkComputationNode,
    ) -> Self:
        """
        Instantiate a `DatasetSinkComputeNodeDefinition` from its high level representation.

        **Parameters**:
        - `id`: ID of the `DatasetSinkComputeNodeDefinition`.
        - `name`: Name of the `DatasetSinkComputeNodeDefinition`.
        - `node`: Pydantic model of the `DatasetSinkComputationNode`.
        """
        return cls(
            name=name,
            dataset_name=node.input.datasetName,
            dependency=node.input.dependency,
            encryption_key_dependency=node.encryptionKeyDependency.dependency,
            is_key_hex_encoded=node.encryptionKeyDependency.isKeyHexEncoded,
            input_type=cls._get_input_type_from_high_level(node.input),
            id=id,
        )

    @staticmethod
    def _get_input_type_from_high_level(
        input: DatasetSinkInput,
    ) -> Union[SinkInputFormatRaw | SinkInputZipAll | SinkInputZipFiles]:
        input_data_type = input.inputDataType.root
        fields = input_data_type.model_fields
        if "raw" in fields:
            return SinkInputFormat.raw()
        elif "zip" in fields:
            zip_type = input_data_type.zip.root
            zip_type_fields = zip_type.model_fields
            if "all" in zip_type_fields:
                return SinkInputFormat.all()
            elif "files" in zip_type_fields:
                return SinkInputFormat.files(files=zip_type.files)
            else:
                raise Exception(f"Unknown zip type {zip_type}")
        else:
            raise Exception(f"Unknown input data type {input.inputDataType}")

    def build(
        self,
        dcr_id: str,
        node_definition: NodeDefinition,
        client: Client,
        session: Session,
    ) -> DatasetSinkComputeNode:
        """
        Construct a `DatasetSinkComputeNode` from the definition.

        **Parameters**:
        - `dcr_id`: ID of the DCR the node is a member of.
        - `node_definition`: Definition of the DatasetSink Compute Node.
        - `client`: A `Client` object which can be used to perform operations such as uploading data
            and retrieving computation results.
        - `session`: The session with which to communicate with the enclave.
        """
        return DatasetSinkComputeNode(
            name=self.name,
            dcr_id=dcr_id,
            client=client,
            session=session,
            node_definition=node_definition,
            id=self.id,
        )


class DatasetSinkComputeNode(ComputationNode):
    """
    A DatasetSinkComputeNode is a node that can write datasets to the Decentriq Platform.
    These datasets can be used in the Decentriq UI as if they were uploaded or imported directly.

    Note that DCRs containing this type of node cannot be interacted with through the Decentriq UI.
    """

    def __init__(
        self,
        id: str,
        name: str,
        dcr_id: str,
        client: Client,
        session: Session,
        node_definition: NodeDefinition,
    ) -> None:
        """
        Initialise a `DatasetSinkComputeNode`.

        **Parameters**:
        - `id`: ID of the `DatasetSinkComputeNode`
        - `name`: Name of the `DatasetSinkComputeNode`.
        - `dcr_id`: ID of the DCR the node is a member of.
        - `client`: A `Client` object which can be used to perform operations such as uploading data
            and retrieving computation results.
        - `session`: The session with which to communicate with the enclave.
        - `node_definition`: The definition of the `DatasetSinkComputeNode`.
        """
        super().__init__(
            name=name,
            client=client,
            session=session,
            dcr_id=dcr_id,
            id=id,
            definition=node_definition,
        )

    def _get_computation_id(self) -> str:
        """
        Retrieve the ID of the node corresponding to the computation.
        """
        return self.id

    def store_dataset_key(self, key: Key) -> Dict[str, Any]:
        """
        Store the dataset to the Decentriq Platform and add an entry to
        the secret store for the encryption key used to encrypt the dataset.
        """
        result = self.run_computation_and_get_results_as_bytes()
        result_zip = zipfile.ZipFile(io.BytesIO(result), "r")
        datasets_json = json.loads(result_zip.read("datasets.json").decode())
        session_v2 = self.client.create_session_v2()
        for dataset in datasets_json["datasets"]:
            manifest_hash = dataset["manifestHash"]
            encryption_key_secret = Secret(
                secret=key.material,
                state=SecretStoreEntryState.model_validate(
                    {
                        "version": "V0",
                        "acl": {
                            "type": "UsersList",
                            "users": [
                                {
                                    "id": self.client.user_email,
                                    "role": "Owner",
                                },
                            ],
                        },
                        "type": "DatasetKey",
                        "manifest_hash": manifest_hash,
                    }
                ),
            )
            session_v2.create_secret(encryption_key_secret)

            # TODO: Add dataset metadata to the secret store once the storing of the dataset metadata is tidied up.
            # # Store the dataset metadata if the dataset has a schema.
            # # This identifies the dataset as a "table" type.
            # if "schemaBase64" in dataset:
            #     dataset_metadata_secret = Secret(
            #         secret=dataset["schemaBase64"].encode("utf-8"),
            #         state=SecretStoreEntryState.model_validate(
            #             {
            #                 "version": "V0",
            #                 "acl": {
            #                     "type": "UsersList",
            #                     "users": [
            #                         {
            #                             "id": self.client.user_email,
            #                             "role": "Owner",
            #                         },
            #                     ],
            #                 },
            #                 "type": "DatasetMetadata",
            #                 "manifest_hash": manifest_hash,
            #             }
            #         ),
            #     )
            #     session_v2.create_secret(dataset_metadata_secret)

        return datasets_json["datasets"]



from __future__ import annotations

import json
from enum import Enum
from typing import TYPE_CHECKING, Dict, Optional

from decentriq_dcr_compiler.schemas import S3SinkComputationNode
from typing_extensions import Self

from ..session import Session
from .high_level_node import ComputationNode
from .node_definitions import NodeDefinition

if TYPE_CHECKING:
    from ..client import Client


class S3Provider(str, Enum):
    AWS = "Aws"
    GCS = "Gcs"


class S3SinkComputeNodeDefinition(NodeDefinition):
    """
    Class representing an S3 Sink Computation node.
    """

    def __init__(
        self,
        name: str,
        credentials_dependency_id: str,
        endpoint: str,
        region: str,
        dependency: str,
        provider: S3Provider = S3Provider.AWS,
        id: Optional[str] = None,
    ) -> None:
        """
        Initialise a `S3SinkComputeNodeDefinition`:

        **Parameters**:
        `name`: Name of the `S3SinkComputeNodeDefinition`.
        `credentials_dependency_id`: ID of the `S3SinkComputeNodeDefinition` dependency.
        `endpoint`: Endpoint where data will be uploaded.
        `region`: Region where the data will be uploaded.
        `dependency`: Node that the `S3SinkComputeNodeDefinition` depends on.
        `provider`: Type of S3 provider (AWS/GCS).
        `id`: Optional ID of the `S3SinkComputeNodeDefinition`.
        """
        super().__init__(name=name, id=id or name)
        self.credentials_dependency_id = credentials_dependency_id
        self.endpoint = endpoint
        self.region = region
        self.dependency = dependency
        self.provider = provider
        self.specification_id = "decentriq.s3-sink-worker"

    @property
    def required_workers(self):
        return [self.specification_id]

    def _get_high_level_representation(self) -> Dict[str, str]:
        """
        Retrieve the high level representation of the `S3SinkComputeNodeDefinition`.
        """
        computation_node = {
            "id": self.id,
            "name": self.name,
            "kind": {
                "computation": {
                    "kind": {
                        "s3Sink": {
                            "credentialsDependencyId": self.credentials_dependency_id,
                            "endpoint": self.endpoint,
                            "region": self.region,
                            "s3Provider": self.provider.value,
                            "specificationId": self.specification_id,
                            "uploadDependencyId": self.dependency,
                        }
                    }
                },
            },
        }
        return computation_node

    @classmethod
    def _from_high_level(cls, id: str, name: str, node: S3SinkComputationNode) -> Self:
        """
        Instantiate a `S3SinkComputeNodeDefinition` from its high level representation.

        **Parameters**:
        - `name`: Name of the `S3SinkComputeNodeDefinition`.
        - `node`: Pydantic model of the `S3SinkComputeNode`.
        """
        s3_sink_node = json.loads(node.model_dump_json())
        return cls(
            name=name,
            credentials_dependency_id=s3_sink_node["credentialsDependencyId"],
            endpoint=s3_sink_node["endpoint"],
            region=s3_sink_node["region"],
            dependency=s3_sink_node["uploadDependencyId"],
            provider=s3_sink_node["s3Provider"],
            id=id,
        )

    def build(
        self,
        dcr_id: str,
        node_definition: NodeDefinition,
        client: Client,
        session: Session,
    ) -> S3SinkComputeNode:
        """
        Construct a S3SinkComputeNode from the Node Definition.

        **Parameters**:
        - `dcr_id`: ID of the DCR the node is a member of.
        - `node_definition`: Definition of the S3 Sink Compute Node.
        - `client`: A `Client` object which can be used to perform operations such as uploading data
            and retrieving computation results.
        - `session`: The session with which to communicate with the enclave.
        """
        return S3SinkComputeNode(
            name=self.name,
            dcr_id=dcr_id,
            credentials_dependency_id=self.credentials_dependency_id,
            endpoint=self.endpoint,
            region=self.region,
            dependency=self.dependency,
            client=client,
            session=session,
            node_definition=node_definition,
            id=self.id,
            provider=self.provider,
        )


class S3SinkComputeNode(ComputationNode):
    """
    A type of node that can be used to export data to either AWS or Google Cloud Storage.

    Note that DCRs containing this type of node cannot be interacted with through the Decentriq UI.
    """

    def __init__(
        self,
        id: str,
        name: str,
        dcr_id: str,
        credentials_dependency_id: str,
        endpoint: str,
        region: str,
        dependency: str,
        client: Client,
        session: Session,
        node_definition: NodeDefinition,
        provider: Optional[S3Provider] = S3Provider.AWS,
    ) -> None:
        """
        Initialise a `S3SinkComputeNode`:

        **Parameters**:
        - `id`: ID of the `S3SinkComputeNode`.
        - `name`: Name of the `S3SinkComputeNode`.
        - `dcr_id`: ID of the DCR the node is a member of.
        - `credentials_dependency_id`: ID of the `S3SinkComputeNode` dependency.
        - `endpoint`: Endpoint where data will be uploaded.
        - `region`: Region where the data will be uploaded.
        - `dependency`: Node that the `S3SinkComputeNode` depends on.
        - `client`: A `Client` object which can be used to perform operations such as uploading data
            and retrieving computation results.
        - `session`: The session with which to communicate with the enclave.
        - `node_definition`: Definition of the Raw Data Node.
        - `provider`: Type of S3 provider (AWS/GCS).
        """
        super().__init__(
            name=name,
            client=client,
            session=session,
            dcr_id=dcr_id,
            id=id,
            definition=node_definition,
        )
        self.credentials_dependency_id = credentials_dependency_id
        self.endpoint = endpoint
        self.region = region
        self.upload_dependency_id = dependency
        self.provider = provider
        self.specification_id = "decentriq.s3-sink-worker"

    def _get_computation_id(self) -> str:
        """
        Retrieve the ID of the node corresponding to the computation.
        """
        return self.id



from typing import List, Optional

from google.protobuf.json_format import MessageToDict

from ...proto import (
    ComputeNodeFormat,
    parse_length_delimited,
    serialize_length_delimited,
)
from ..node import Node
from .proto import DatasetSinkWorkerConfiguration, SinkInput

__docformat__ = "restructuredtext"
__pdoc__ = {
    "proto": False,
}


class DatasetSink(Node):
    """
    Compute node that re-encrypts input data with a user-provided key
    and creates a dataset entry in the database.
    This node allows users to store the result of a computation as a
    separate dataset that can be published to other Data Clean Rooms.
    """

    def __init__(
        self,
        name: str,
        inputs: List[SinkInput],
        encryption_key_dependency: str,
        dataset_import_id: Optional[str] = None,
        is_key_hex_encoded: bool = False,
    ) -> None:
        """
        Create a dataset sink node.

        **Parameters**:
        - `name`: A human-readable identifier of the node.
        - `inputs`: The data sources from which to read. The given
            encryption key will be used to encrypt all datasets derived
            from these inputs.
            Each input can either be a single raw input (for example,
            when reading a whole ZIP archive), or one ore more files
            contained in an input ZIP file. For each file contained
            in the selection, a separate dataset will be created.
        - `encryption_key_dependency`: The id of the node that provides
            the encryption key to be used. In most cases, this will be a
            data node to which the binary encryption key will be published.
        - `dataset_import_id`: The identifier of the associated `DatasetImport`.
            When using this node directly, this argument can be ommited.
        - `is_key_hex_encoded`: Whether the encryption key material provided
            by the node serving the key is hex-encoded. If this flag is set,
            the node will try to decode the given key.
        """
        config = DatasetSinkWorkerConfiguration(
            inputs=inputs,
            encryptionKeyDependency=encryption_key_dependency,
            datasetImportId=dataset_import_id,
            isKeyHexEncoded=is_key_hex_encoded,
        )
        config_serialized = serialize_length_delimited(config)
        dependencies = [input.dependency for input in inputs] + [
            encryption_key_dependency
        ]
        super().__init__(
            name,
            config=config_serialized,
            enclave_type="decentriq.dataset-sink-worker",
            dependencies=dependencies,
            output_format=ComputeNodeFormat.ZIP,
        )


from ...decoder import DatasetSinkWorkerConfiguration
from .helpers import store_computation_result_as_dataset

__all__ = ["DatasetSink", "store_computation_result_as_dataset"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: data_source_snowflake.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'data_source_snowflake.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x64\x61ta_source_snowflake.proto\x12\x15\x64\x61ta_source_snowflake\"x\n\x0fSnowflakeSource\x12\x15\n\rwarehouseName\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x61tabaseName\x18\x02 \x01(\t\x12\x12\n\nschemaName\x18\x03 \x01(\t\x12\x11\n\ttableName\x18\x04 \x01(\t\x12\x11\n\tstageName\x18\x05 \x01(\t\"\x7f\n&DataSourceSnowflakeWorkerConfiguration\x12\x36\n\x06source\x18\x01 \x01(\x0b\x32&.data_source_snowflake.SnowflakeSource\x12\x1d\n\x15\x63redentialsDependency\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_source_snowflake_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SNOWFLAKESOURCE']._serialized_start=54
  _globals['_SNOWFLAKESOURCE']._serialized_end=174
  _globals['_DATASOURCESNOWFLAKEWORKERCONFIGURATION']._serialized_start=176
  _globals['_DATASOURCESNOWFLAKEWORKERCONFIGURATION']._serialized_end=303
# @@protoc_insertion_point(module_scope)



from typing import Any, Dict, List, Optional, Union
from dataclasses import dataclass
from decentriq_dcr_compiler._schemas.data_science_data_room import (
    ExportNodeDependency as ExportNodeDependencySchema,
)


class ExportDependency:
    def __init__(
        self, high_level: Dict[str, Any], object_key: Optional[str] = None
    ) -> None:
        self.high_level = high_level
        self.object_key = object_key


class ExportNodeDependency:
    """
    Factory for creating the desired `ExportNodeDependency` type.
    """

    @staticmethod
    def raw(name: str, object_key: str) -> ExportDependency:
        """
        Construct an export dependency node which will export a raw file.

        **Parameters**:
        - `name`: Name of the export node dependency.
        - `object_key`: The name of the object when exported.
        """
        return ExportDependency({"name": name, "exportType": {"raw": ()}}, object_key)

    @staticmethod
    def all(name: str) -> ExportDependency:
        """
        Construct an export dependency node which will export all files in a zip.
        The names of the files in the zip will be used as the object names when exported.
        
        **Parameters**:
        - `name`: Name of the export node dependency.
        """
        return ExportDependency({"name": name, "exportType": {"zipAllFiles": ()}})

    @staticmethod
    def file(name: str, file: str, object_key: str) -> ExportDependency:
        """
        Construct an export dependency node which will export a single file in a zip.
        
        **Parameters**:
        - `name`: Name of the export node dependency.
        - `file`: Name of the file within the zip to be exported.
        - `object_key`: The name of the object when exported.
        """
        return ExportDependency(
            {"name": name, "exportType": {"zipSingleFile": file}}, object_key
        )


def _get_export_node_dependency_from_high_level(
    dependency: ExportNodeDependencySchema, object_key: str
):
    dependency_name = dependency.name
    dependency_export_type = dependency.exportType.root
    dependency_export_type_fields = dependency_export_type.model_fields

    if "raw" in dependency_export_type_fields:
        return ExportNodeDependency.raw(dependency_name, object_key)
    elif "zipSingleFile" in dependency_export_type_fields:
        return ExportNodeDependency.file(
            dependency_name, dependency_export_type.zipSingleFile, object_key
        )
    elif "zipAllFiles" in dependency_export_type_fields:
        return ExportNodeDependency.all(dependency_name)
    else:
        raise Exception(
            f"Unknown dependency export type field {dependency_export_type_fields}"
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: attestation.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'attestation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ttestation.proto\x12\x0b\x61ttestation\"\xfd\x01\n\x08\x46\x61tquote\x12)\n\x04\x65pid\x18\x01 \x01(\x0b\x32\x19.attestation.FatquoteEpidH\x00\x12)\n\x04\x64\x63\x61p\x18\x02 \x01(\x0b\x32\x19.attestation.FatquoteDcapH\x00\x12+\n\x05nitro\x18\x03 \x01(\x0b\x32\x1a.attestation.FatquoteNitroH\x00\x12\'\n\x03snp\x18\x04 \x01(\x0b\x32\x18.attestation.FatquoteSnpH\x00\x12\x39\n\x0c\x64\x63\x61pMrsigner\x18\x05 \x01(\x0b\x32!.attestation.FatquoteDcapMrsignerH\x00\x42\n\n\x08\x66\x61tquote\"k\n\x0c\x46\x61tquoteEpid\x12\x17\n\x0fiasResponseBody\x18\x01 \x01(\x0c\x12\x16\n\x0eiasCertificate\x18\x02 \x01(\x0c\x12\x14\n\x0ciasSignature\x18\x03 \x01(\x0c\x12\x14\n\x0ciasRootCaDer\x18\x04 \x01(\x0c\"\x86\x01\n\x0c\x46\x61tquoteDcap\x12\x11\n\tdcapQuote\x18\x01 \x01(\x0c\x12\x0f\n\x07tcbInfo\x18\x02 \x01(\x0c\x12\x12\n\nqeIdentity\x18\x03 \x01(\x0c\x12\x13\n\x0btcbSignCert\x18\x04 \x01(\x0c\x12\x12\n\nqeSignCert\x18\x05 \x01(\x0c\x12\x15\n\rdcapRootCaDer\x18\x06 \x01(\x0c\"\xc7\x01\n\x14\x46\x61tquoteDcapMrsigner\x12\x11\n\tdcapQuote\x18\x01 \x01(\x0c\x12\x0f\n\x07tcbInfo\x18\x02 \x01(\x0c\x12\x12\n\nqeIdentity\x18\x03 \x01(\x0c\x12\x13\n\x0btcbSignCert\x18\x04 \x01(\x0c\x12\x12\n\nqeSignCert\x18\x05 \x01(\x0c\x12\x15\n\rdcapRootCaDer\x18\x06 \x01(\x0c\x12\x37\n\x10sigstoreEvidence\x18\x07 \x01(\x0b\x32\x1d.attestation.SigstoreEvidence\".\n\x0cSigstoreFile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63ontents\x18\x02 \x01(\x0c\"V\n\x10SigstoreEvidence\x12-\n\x02v1\x18\x01 \x01(\x0b\x32\x1f.attestation.SigstoreEvidenceV1H\x00\x42\x13\n\x11sigstore_evidence\"Y\n\x12SigstoreEvidenceV1\x12(\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x19.attestation.SigstoreFile\x12\x19\n\x11rekorLogEntryJson\x18\x02 \x01(\x0c\"5\n\rFatquoteNitro\x12\x0c\n\x04\x63ose\x18\x01 \x01(\x0c\x12\x16\n\x0enitroRootCaDer\x18\x02 \x01(\x0c\"\xdf\x01\n\x0b\x46\x61tquoteSnp\x12\x11\n\treportBin\x18\x01 \x01(\x0c\x12\x11\n\tamdArkDer\x18\x02 \x01(\x0c\x12\x11\n\tamdSevDer\x18\x03 \x01(\x0c\x12\x12\n\nvcekCrtDer\x18\x04 \x01(\x0c\x12\x12\n\nreportData\x18\x05 \x01(\x0c\x12\x17\n\x0froughtimePubKey\x18\x06 \x01(\x0c\x12\x16\n\x0eroughtimeNonce\x18\x07 \x01(\x0c\x12\x17\n\x0fsignedTimestamp\x18\x08 \x01(\x0c\x12\x14\n\x0c\x64\x65\x63\x65ntriqDer\x18\t \x01(\x0c\x12\x0f\n\x07\x63hipDer\x18\n \x01(\x0c\"\x98\x03\n\x18\x41ttestationSpecification\x12\x43\n\tintelEpid\x18\x01 \x01(\x0b\x32..attestation.AttestationSpecificationIntelEpidH\x00\x12\x43\n\tintelDcap\x18\x02 \x01(\x0b\x32..attestation.AttestationSpecificationIntelDcapH\x00\x12\x41\n\x08\x61wsNitro\x18\x03 \x01(\x0b\x32-.attestation.AttestationSpecificationAwsNitroH\x00\x12=\n\x06\x61mdSnp\x18\x04 \x01(\x0b\x32+.attestation.AttestationSpecificationAmdSnpH\x00\x12S\n\x11intelDcapMrsigner\x18\x05 \x01(\x0b\x32\x36.attestation.AttestationSpecificationIntelDcapMrsignerH\x00\x42\x1b\n\x19\x61ttestation_specification\"\xa2\x01\n!AttestationSpecificationIntelEpid\x12\x11\n\tmrenclave\x18\x01 \x01(\x0c\x12\x14\n\x0ciasRootCaDer\x18\x02 \x01(\x0c\x12\x13\n\x0b\x61\x63\x63\x65ptDebug\x18\x03 \x01(\x08\x12\x1c\n\x14\x61\x63\x63\x65ptGroupOutOfDate\x18\x04 \x01(\x08\x12!\n\x19\x61\x63\x63\x65ptConfigurationNeeded\x18\x05 \x01(\x08\"\xb5\x01\n!AttestationSpecificationIntelDcap\x12\x11\n\tmrenclave\x18\x01 \x01(\x0c\x12\x15\n\rdcapRootCaDer\x18\x02 \x01(\x0c\x12\x13\n\x0b\x61\x63\x63\x65ptDebug\x18\x03 \x01(\x08\x12\x17\n\x0f\x61\x63\x63\x65ptOutOfDate\x18\x04 \x01(\x08\x12!\n\x19\x61\x63\x63\x65ptConfigurationNeeded\x18\x05 \x01(\x08\x12\x15\n\racceptRevoked\x18\x06 \x01(\x08\"r\n AttestationSpecificationAwsNitro\x12\x16\n\x0enitroRootCaDer\x18\x01 \x01(\x0c\x12\x0c\n\x04pcr0\x18\x02 \x01(\x0c\x12\x0c\n\x04pcr1\x18\x03 \x01(\x0c\x12\x0c\n\x04pcr2\x18\x04 \x01(\x0c\x12\x0c\n\x04pcr8\x18\x05 \x01(\x0c\"\x92\x01\n\x1e\x41ttestationSpecificationAmdSnp\x12\x11\n\tamdArkDer\x18\x01 \x01(\x0c\x12\x13\n\x0bmeasurement\x18\x02 \x01(\x0c\x12\x17\n\x0froughtimePubKey\x18\x03 \x01(\x0c\x12\x19\n\x11\x61uthorizedChipIds\x18\x04 \x03(\x0c\x12\x14\n\x0c\x64\x65\x63\x65ntriqDer\x18\x05 \x01(\x0c\"\xed\x01\n)AttestationSpecificationIntelDcapMrsigner\x12\x10\n\x08mrsigner\x18\x01 \x01(\x0c\x12\x15\n\rdcapRootCaDer\x18\x02 \x01(\x0c\x12\x13\n\x0b\x61\x63\x63\x65ptDebug\x18\x03 \x01(\x08\x12\x17\n\x0f\x61\x63\x63\x65ptOutOfDate\x18\x04 \x01(\x08\x12!\n\x19\x61\x63\x63\x65ptConfigurationNeeded\x18\x05 \x01(\x08\x12\x15\n\racceptRevoked\x18\x06 \x01(\x08\x12\x11\n\tisvprodid\x18\x07 \x01(\r\x12\x1c\n\x14sigstoreRootOlpcJson\x18\x08 \x01(\x0c\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'attestation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FATQUOTE']._serialized_start=35
  _globals['_FATQUOTE']._serialized_end=288
  _globals['_FATQUOTEEPID']._serialized_start=290
  _globals['_FATQUOTEEPID']._serialized_end=397
  _globals['_FATQUOTEDCAP']._serialized_start=400
  _globals['_FATQUOTEDCAP']._serialized_end=534
  _globals['_FATQUOTEDCAPMRSIGNER']._serialized_start=537
  _globals['_FATQUOTEDCAPMRSIGNER']._serialized_end=736
  _globals['_SIGSTOREFILE']._serialized_start=738
  _globals['_SIGSTOREFILE']._serialized_end=784
  _globals['_SIGSTOREEVIDENCE']._serialized_start=786
  _globals['_SIGSTOREEVIDENCE']._serialized_end=872
  _globals['_SIGSTOREEVIDENCEV1']._serialized_start=874
  _globals['_SIGSTOREEVIDENCEV1']._serialized_end=963
  _globals['_FATQUOTENITRO']._serialized_start=965
  _globals['_FATQUOTENITRO']._serialized_end=1018
  _globals['_FATQUOTESNP']._serialized_start=1021
  _globals['_FATQUOTESNP']._serialized_end=1244
  _globals['_ATTESTATIONSPECIFICATION']._serialized_start=1247
  _globals['_ATTESTATIONSPECIFICATION']._serialized_end=1655
  _globals['_ATTESTATIONSPECIFICATIONINTELEPID']._serialized_start=1658
  _globals['_ATTESTATIONSPECIFICATIONINTELEPID']._serialized_end=1820
  _globals['_ATTESTATIONSPECIFICATIONINTELDCAP']._serialized_start=1823
  _globals['_ATTESTATIONSPECIFICATIONINTELDCAP']._serialized_end=2004
  _globals['_ATTESTATIONSPECIFICATIONAWSNITRO']._serialized_start=2006
  _globals['_ATTESTATIONSPECIFICATIONAWSNITRO']._serialized_end=2120
  _globals['_ATTESTATIONSPECIFICATIONAMDSNP']._serialized_start=2123
  _globals['_ATTESTATIONSPECIFICATIONAMDSNP']._serialized_end=2269
  _globals['_ATTESTATIONSPECIFICATIONINTELDCAPMRSIGNER']._serialized_start=2272
  _globals['_ATTESTATIONSPECIFICATIONINTELDCAPMRSIGNER']._serialized_end=2509
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: integrity_store.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'integrity_store.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15integrity_store.proto\x12\x13integrity_store_api\"b\n\x15IntegrityStoreRequest\x12>\n\x03\x63\x61s\x18\x01 \x01(\x0b\x32/.integrity_store_api.BatchCompareAndSwapRequestH\x00\x42\t\n\x07request\"e\n\x16IntegrityStoreResponse\x12?\n\x03\x63\x61s\x18\x01 \x01(\x0b\x32\x30.integrity_store_api.BatchCompareAndSwapResponseH\x00\x42\n\n\x08response\"Z\n\x1a\x42\x61tchCompareAndSwapRequest\x12<\n\x08requests\x18\x01 \x03(\x0b\x32*.integrity_store_api.CompareAndSwapRequest\"]\n\x1b\x42\x61tchCompareAndSwapResponse\x12>\n\tresponses\x18\x01 \x03(\x0b\x32+.integrity_store_api.CompareAndSwapResponse\"\xbb\x01\n\x15\x43ompareAndSwapRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x02 \x01(\t\x12\x1d\n\x10\x65xpectedCasIndex\x18\x03 \x01(\x04H\x00\x88\x01\x01\x12?\n\x08newValue\x18\x04 \x01(\x0b\x32(.integrity_store_api.IntegrityStoreValueH\x01\x88\x01\x01\x42\x13\n\x11_expectedCasIndexB\x0b\n\t_newValue\"\xb5\x01\n\x16\x43ompareAndSwapResponse\x12\x0f\n\x07swapped\x18\x01 \x01(\x08\x12\x1d\n\x10previousCasIndex\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x44\n\rpreviousValue\x18\x03 \x01(\x0b\x32(.integrity_store_api.IntegrityStoreValueH\x01\x88\x01\x01\x42\x13\n\x11_previousCasIndexB\x10\n\x0e_previousValue\"\xc6\x01\n\x13IntegrityStoreValue\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x1d\n\x10plaintextContent\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12plaintextSignature\x18\x03 \x01(\x0cH\x01\x88\x01\x01\x12\x1d\n\x10\x65ncryptedContent\x18\x04 \x01(\x0cH\x02\x88\x01\x01\x42\x13\n\x11_plaintextContentB\x15\n\x13_plaintextSignatureB\x13\n\x11_encryptedContentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'integrity_store_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_INTEGRITYSTOREREQUEST']._serialized_start=46
  _globals['_INTEGRITYSTOREREQUEST']._serialized_end=144
  _globals['_INTEGRITYSTORERESPONSE']._serialized_start=146
  _globals['_INTEGRITYSTORERESPONSE']._serialized_end=247
  _globals['_BATCHCOMPAREANDSWAPREQUEST']._serialized_start=249
  _globals['_BATCHCOMPAREANDSWAPREQUEST']._serialized_end=339
  _globals['_BATCHCOMPAREANDSWAPRESPONSE']._serialized_start=341
  _globals['_BATCHCOMPAREANDSWAPRESPONSE']._serialized_end=434
  _globals['_COMPAREANDSWAPREQUEST']._serialized_start=437
  _globals['_COMPAREANDSWAPREQUEST']._serialized_end=624
  _globals['_COMPAREANDSWAPRESPONSE']._serialized_start=627
  _globals['_COMPAREANDSWAPRESPONSE']._serialized_end=808
  _globals['_INTEGRITYSTOREVALUE']._serialized_start=811
  _globals['_INTEGRITYSTOREVALUE']._serialized_end=1009
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import compute_sql_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SyntheticDataConf(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMNS_FIELD_NUMBER: builtins.int
    OUTPUTORIGINALDATASTATS_FIELD_NUMBER: builtins.int
    EPSILON_FIELD_NUMBER: builtins.int
    outputOriginalDataStats: builtins.bool
    epsilon: builtins.float
    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Column]: ...
    def __init__(
        self,
        *,
        columns: collections.abc.Iterable[global___Column] | None = ...,
        outputOriginalDataStats: builtins.bool = ...,
        epsilon: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["columns", b"columns", "epsilon", b"epsilon", "outputOriginalDataStats", b"outputOriginalDataStats"]) -> None: ...

global___SyntheticDataConf = SyntheticDataConf

@typing.final
class Mask(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _MaskFormat:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _MaskFormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Mask._MaskFormat.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        GENERIC_STRING: Mask._MaskFormat.ValueType  # 0
        GENERIC_NUMBER: Mask._MaskFormat.ValueType  # 1
        NAME: Mask._MaskFormat.ValueType  # 2
        ADDRESS: Mask._MaskFormat.ValueType  # 3
        POSTCODE: Mask._MaskFormat.ValueType  # 4
        PHONE_NUMBER: Mask._MaskFormat.ValueType  # 5
        SOCIAL_SECURITY_NUMBER: Mask._MaskFormat.ValueType  # 6
        EMAIL: Mask._MaskFormat.ValueType  # 7
        DATE: Mask._MaskFormat.ValueType  # 8
        TIMESTAMP: Mask._MaskFormat.ValueType  # 9
        IBAN: Mask._MaskFormat.ValueType  # 10

    class MaskFormat(_MaskFormat, metaclass=_MaskFormatEnumTypeWrapper): ...
    GENERIC_STRING: Mask.MaskFormat.ValueType  # 0
    GENERIC_NUMBER: Mask.MaskFormat.ValueType  # 1
    NAME: Mask.MaskFormat.ValueType  # 2
    ADDRESS: Mask.MaskFormat.ValueType  # 3
    POSTCODE: Mask.MaskFormat.ValueType  # 4
    PHONE_NUMBER: Mask.MaskFormat.ValueType  # 5
    SOCIAL_SECURITY_NUMBER: Mask.MaskFormat.ValueType  # 6
    EMAIL: Mask.MaskFormat.ValueType  # 7
    DATE: Mask.MaskFormat.ValueType  # 8
    TIMESTAMP: Mask.MaskFormat.ValueType  # 9
    IBAN: Mask.MaskFormat.ValueType  # 10

    FORMAT_FIELD_NUMBER: builtins.int
    format: global___Mask.MaskFormat.ValueType
    def __init__(
        self,
        *,
        format: global___Mask.MaskFormat.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["format", b"format"]) -> None: ...

global___Mask = Mask

@typing.final
class Column(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDEX_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MASK_FIELD_NUMBER: builtins.int
    index: builtins.int
    @property
    def type(self) -> compute_sql_pb2.ColumnType: ...
    @property
    def mask(self) -> global___Mask: ...
    def __init__(
        self,
        *,
        index: builtins.int = ...,
        type: compute_sql_pb2.ColumnType | None = ...,
        mask: global___Mask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["mask", b"mask", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["index", b"index", "mask", b"mask", "type", b"type"]) -> None: ...

global___Column = Column



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PrimitiveType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PrimitiveTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PrimitiveType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INT64: _PrimitiveType.ValueType  # 0
    STRING: _PrimitiveType.ValueType  # 1
    FLOAT64: _PrimitiveType.ValueType  # 2

class PrimitiveType(_PrimitiveType, metaclass=_PrimitiveTypeEnumTypeWrapper): ...

INT64: PrimitiveType.ValueType  # 0
STRING: PrimitiveType.ValueType  # 1
FLOAT64: PrimitiveType.ValueType  # 2
global___PrimitiveType = PrimitiveType

@typing.final
class SqlWorkerConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATION_FIELD_NUMBER: builtins.int
    COMPUTATION_FIELD_NUMBER: builtins.int
    @property
    def validation(self) -> global___ValidationConfiguration: ...
    @property
    def computation(self) -> global___ComputationConfiguration: ...
    def __init__(
        self,
        *,
        validation: global___ValidationConfiguration | None = ...,
        computation: global___ComputationConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["computation", b"computation", "configuration", b"configuration", "validation", b"validation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["computation", b"computation", "configuration", b"configuration", "validation", b"validation"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["configuration", b"configuration"]) -> typing.Literal["validation", "computation"] | None: ...

global___SqlWorkerConfiguration = SqlWorkerConfiguration

@typing.final
class ValidationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLESCHEMA_FIELD_NUMBER: builtins.int
    @property
    def tableSchema(self) -> global___TableSchema: ...
    def __init__(
        self,
        *,
        tableSchema: global___TableSchema | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tableSchema", b"tableSchema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["tableSchema", b"tableSchema"]) -> None: ...

global___ValidationConfiguration = ValidationConfiguration

@typing.final
class TableSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMEDCOLUMNS_FIELD_NUMBER: builtins.int
    @property
    def namedColumns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamedColumn]: ...
    def __init__(
        self,
        *,
        namedColumns: collections.abc.Iterable[global___NamedColumn] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["namedColumns", b"namedColumns"]) -> None: ...

global___TableSchema = TableSchema

@typing.final
class NamedColumn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    COLUMNTYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def columnType(self) -> global___ColumnType: ...
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        columnType: global___ColumnType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_name", b"_name", "columnType", b"columnType", "name", b"name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_name", b"_name", "columnType", b"columnType", "name", b"name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_name", b"_name"]) -> typing.Literal["name"] | None: ...

global___NamedColumn = NamedColumn

@typing.final
class ColumnType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIMITIVETYPE_FIELD_NUMBER: builtins.int
    NULLABLE_FIELD_NUMBER: builtins.int
    primitiveType: global___PrimitiveType.ValueType
    nullable: builtins.bool
    def __init__(
        self,
        *,
        primitiveType: global___PrimitiveType.ValueType = ...,
        nullable: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["nullable", b"nullable", "primitiveType", b"primitiveType"]) -> None: ...

global___ColumnType = ColumnType

@typing.final
class TableDependencyMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_FIELD_NUMBER: builtins.int
    DEPENDENCY_FIELD_NUMBER: builtins.int
    table: builtins.str
    """Name of the table as it appears in the SQL query string"""
    dependency: builtins.str
    """ID of the compute/data node that provides data for this table"""
    def __init__(
        self,
        *,
        table: builtins.str = ...,
        dependency: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dependency", b"dependency", "table", b"table"]) -> None: ...

global___TableDependencyMapping = TableDependencyMapping

@typing.final
class ComputationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SQLSTATEMENT_FIELD_NUMBER: builtins.int
    PRIVACYSETTINGS_FIELD_NUMBER: builtins.int
    CONSTRAINTS_FIELD_NUMBER: builtins.int
    TABLEDEPENDENCYMAPPINGS_FIELD_NUMBER: builtins.int
    sqlStatement: builtins.str
    @property
    def privacySettings(self) -> global___PrivacySettings: ...
    @property
    def constraints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Constraint]: ...
    @property
    def tableDependencyMappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableDependencyMapping]: ...
    def __init__(
        self,
        *,
        sqlStatement: builtins.str = ...,
        privacySettings: global___PrivacySettings | None = ...,
        constraints: collections.abc.Iterable[global___Constraint] | None = ...,
        tableDependencyMappings: collections.abc.Iterable[global___TableDependencyMapping] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["privacySettings", b"privacySettings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["constraints", b"constraints", "privacySettings", b"privacySettings", "sqlStatement", b"sqlStatement", "tableDependencyMappings", b"tableDependencyMappings"]) -> None: ...

global___ComputationConfiguration = ComputationConfiguration

@typing.final
class PrivacySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MINAGGREGATIONGROUPSIZE_FIELD_NUMBER: builtins.int
    minAggregationGroupSize: builtins.int
    def __init__(
        self,
        *,
        minAggregationGroupSize: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["minAggregationGroupSize", b"minAggregationGroupSize"]) -> None: ...

global___PrivacySettings = PrivacySettings

@typing.final
class Constraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    description: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description"]) -> None: ...

global___Constraint = Constraint



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: archv2.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import data_room_pb2 as data__room__pb2
from . import release_policy_pb2 as release__policy__pb2
from . import secret_store_pb2 as secret__store__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x61rchv2.proto\x12\x06\x61rchv2\x1a\x0f\x64\x61ta_room.proto\x1a\x14release_policy.proto\x1a\x12secret_store.proto\"\x80\x03\n\rArchV2Request\x12\x33\n\x0c\x63reatePolicy\x18\x01 \x01(\x0b\x32\x1b.archv2.CreatePolicyRequestH\x00\x12;\n\x0bsecretStore\x18\x02 \x01(\x0b\x32$.secret_store_api.SecretStoreRequestH\x00\x12;\n\x0cupdateStatus\x18\x03 \x01(\x0b\x32#.archv2.UpdateDataRoomStatusRequestH\x00\x12?\n\x12getVerificationKey\x18\x04 \x01(\x0b\x32!.archv2.GetVerificationKeyRequestH\x00\x12\x37\n\x0e\x63reateDataRoom\x18\n \x01(\x0b\x32\x1d.archv2.CreateDataRoomRequestH\x00\x12;\n\x10retrieveDataRoom\x18\x0b \x01(\x0b\x32\x1f.archv2.RetrieveDataRoomRequestH\x00\x42\t\n\x07request\"\x9b\x03\n\x0e\x41rchV2Response\x12\x11\n\x07\x66\x61ilure\x18\x01 \x01(\tH\x00\x12\x34\n\x0c\x63reatePolicy\x18\x02 \x01(\x0b\x32\x1c.archv2.CreatePolicyResponseH\x00\x12<\n\x0bsecretStore\x18\x03 \x01(\x0b\x32%.secret_store_api.SecretStoreResponseH\x00\x12<\n\x0cupdateStatus\x18\x04 \x01(\x0b\x32$.archv2.UpdateDataRoomStatusResponseH\x00\x12@\n\x12getVerificationKey\x18\x05 \x01(\x0b\x32\".archv2.GetVerificationKeyResponseH\x00\x12\x38\n\x0e\x63reateDataRoom\x18\n \x01(\x0b\x32\x1e.archv2.CreateDataRoomResponseH\x00\x12<\n\x10retrieveDataRoom\x18\x0b \x01(\x0b\x32 .archv2.RetrieveDataRoomResponseH\x00\x42\n\n\x08response\"\x1b\n\x19GetVerificationKeyRequest\"5\n\x1aGetVerificationKeyResponse\x12\x17\n\x0fverificationKey\x18\x01 \x01(\x0c\"]\n\x15\x43reateDataRoomRequest\x12\x10\n\x08\x64\x61taRoom\x18\x01 \x01(\t\x12\x1d\n\x10\x64\x61taRoomMetadata\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x13\n\x11_dataRoomMetadata\"~\n\x16\x43reateDataRoomResponse\x12\x14\n\ndataRoomId\x18\x01 \x01(\x0cH\x00\x12\x42\n\x17\x64\x61taRoomValidationError\x18\x02 \x01(\x0b\x32\x1f.archv2.DataRoomValidationErrorH\x00\x42\n\n\x08response\"f\n\x13\x43reatePolicyRequest\x12\x31\n\x06policy\x18\x01 \x01(\x0b\x32!.release_policy_api.ReleasePolicy\x12\x12\n\x05scope\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x08\n\x06_scope\"(\n\x14\x43reatePolicyResponse\x12\x10\n\x08policyId\x18\x01 \x01(\t\"Y\n\x1bUpdateDataRoomStatusRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\t\x12&\n\x06status\x18\x02 \x01(\x0e\x32\x16.archv2.DataRoomStatus\"\x1e\n\x1cUpdateDataRoomStatusResponse\"-\n\x17RetrieveDataRoomRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\",\n\x18RetrieveDataRoomResponse\x12\x10\n\x08\x64\x61taRoom\x18\x01 \x01(\t\"\xc6\x02\n\x17\x44\x61taRoomValidationError\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x1c\n\x0fpermissionIndex\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x1a\n\rcomputeNodeId\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1d\n\x10userPermissionId\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\'\n\x1a\x61ttestationSpecificationId\x18\x05 \x01(\tH\x03\x88\x01\x01\x12#\n\x16\x61uthenticationMethodId\x18\x06 \x01(\tH\x04\x88\x01\x01\x42\x12\n\x10_permissionIndexB\x10\n\x0e_computeNodeIdB\x13\n\x11_userPermissionIdB\x1d\n\x1b_attestationSpecificationIdB\x19\n\x17_authenticationMethodId*)\n\x0e\x44\x61taRoomStatus\x12\n\n\x06\x41\x63tive\x10\x00\x12\x0b\n\x07Stopped\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'archv2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DATAROOMSTATUS']._serialized_start=1882
  _globals['_DATAROOMSTATUS']._serialized_end=1923
  _globals['_ARCHV2REQUEST']._serialized_start=84
  _globals['_ARCHV2REQUEST']._serialized_end=468
  _globals['_ARCHV2RESPONSE']._serialized_start=471
  _globals['_ARCHV2RESPONSE']._serialized_end=882
  _globals['_GETVERIFICATIONKEYREQUEST']._serialized_start=884
  _globals['_GETVERIFICATIONKEYREQUEST']._serialized_end=911
  _globals['_GETVERIFICATIONKEYRESPONSE']._serialized_start=913
  _globals['_GETVERIFICATIONKEYRESPONSE']._serialized_end=966
  _globals['_CREATEDATAROOMREQUEST']._serialized_start=968
  _globals['_CREATEDATAROOMREQUEST']._serialized_end=1061
  _globals['_CREATEDATAROOMRESPONSE']._serialized_start=1063
  _globals['_CREATEDATAROOMRESPONSE']._serialized_end=1189
  _globals['_CREATEPOLICYREQUEST']._serialized_start=1191
  _globals['_CREATEPOLICYREQUEST']._serialized_end=1293
  _globals['_CREATEPOLICYRESPONSE']._serialized_start=1295
  _globals['_CREATEPOLICYRESPONSE']._serialized_end=1335
  _globals['_UPDATEDATAROOMSTATUSREQUEST']._serialized_start=1337
  _globals['_UPDATEDATAROOMSTATUSREQUEST']._serialized_end=1426
  _globals['_UPDATEDATAROOMSTATUSRESPONSE']._serialized_start=1428
  _globals['_UPDATEDATAROOMSTATUSRESPONSE']._serialized_end=1458
  _globals['_RETRIEVEDATAROOMREQUEST']._serialized_start=1460
  _globals['_RETRIEVEDATAROOMREQUEST']._serialized_end=1505
  _globals['_RETRIEVEDATAROOMRESPONSE']._serialized_start=1507
  _globals['_RETRIEVEDATAROOMRESPONSE']._serialized_end=1551
  _globals['_DATAROOMVALIDATIONERROR']._serialized_start=1554
  _globals['_DATAROOMVALIDATIONERROR']._serialized_end=1880
# @@protoc_insertion_point(module_scope)



from ..proto import (
    DryRunPermission,
    ExecuteComputePermission,
    ExecuteDevelopmentComputePermission,
    GenerateMergeSignaturePermission,
    LeafCrudPermission,
    MergeConfigurationCommitPermission,
    Permission,
    RetrieveAuditLogPermission,
    RetrieveComputeResultPermission,
    RetrieveDataRoomPermission,
    RetrieveDataRoomStatusPermission,
    RetrievePublishedDatasetsPermission,
    UpdateDataRoomStatusPermission,
)


class Permissions:
    """Helper class for creating data room permissions."""

    def __init__(self):
        """This class is not meant to be instantiated."""

    @staticmethod
    def leaf_crud(leaf_node_id: str) -> Permission:
        """Permission required for publishing a dataset to a data room."""
        return Permission(
            leafCrudPermission=LeafCrudPermission(leafNodeId=leaf_node_id)
        )

    @staticmethod
    def retrieve_data_room() -> Permission:
        """Permission required for retrieving a data room's definition after it has
        been published."""
        return Permission(retrieveDataRoomPermission=RetrieveDataRoomPermission())

    @staticmethod
    def retrieve_audit_log() -> Permission:
        """Permission for retrieving the audit log, a log detailing all past interactions
        with the data room."""
        return Permission(retrieveAuditLogPermission=RetrieveAuditLogPermission())

    @staticmethod
    def execute_compute(compute_node_id: str) -> Permission:
        """Permission for executing the computation with the given id."""
        return Permission(
            executeComputePermission=ExecuteComputePermission(
                computeNodeId=compute_node_id
            )
        )

    @staticmethod
    def retrieve_compute_result(compute_node_id: str) -> Permission:
        """Permission for executing the computation with the given id."""
        return Permission(
            retrieveComputeResultPermission=RetrieveComputeResultPermission(
                computeNodeId=compute_node_id
            )
        )

    @staticmethod
    def retrieve_data_room_status() -> Permission:
        """Permission for retrieving the status of a data room."""
        return Permission(
            retrieveDataRoomStatusPermission=RetrieveDataRoomStatusPermission()
        )

    @staticmethod
    def update_data_room_status() -> Permission:
        """Permission for updating the status of a data room (e.g. irreversibly stopping it)."""
        return Permission(
            updateDataRoomStatusPermission=UpdateDataRoomStatusPermission()
        )

    @staticmethod
    def retrieve_published_datasets() -> Permission:
        """Permission for retrieving the list of datasets that has been published to the data room."""
        return Permission(
            retrievePublishedDatasetsPermission=RetrievePublishedDatasetsPermission()
        )

    @staticmethod
    def dry_run() -> Permission:
        """Permission for triggering a dry run on the data room."""
        return Permission(dryRunPermission=DryRunPermission())

    @staticmethod
    def generate_merge_signature() -> Permission:
        """Permission for generating signatures required for merge approvals."""
        return Permission(
            generateMergeSignaturePermission=GenerateMergeSignaturePermission()
        )

    @staticmethod
    def execute_development_compute() -> Permission:
        """Permission for executing computations in development mode."""
        return Permission(
            executeDevelopmentComputePermission=ExecuteDevelopmentComputePermission()
        )

    @staticmethod
    def merge_configuration_commit() -> Permission:
        """
        Permission for merging configuration commits into the current data
        room configuration.
        """
        return Permission(
            mergeConfigurationCommitPermission=MergeConfigurationCommitPermission()
        )



from typing import List
from decentriq_dcr_compiler import ab_media as ab_media_compiler
from decentriq_dcr_compiler.schemas import AbMediaRequest, AbMediaResponse

from ..channel import Channel
from ..proto import serialize_length_delimited
from ..session import Session


class Request:
    @staticmethod
    def send(request: AbMediaRequest, session: Session) -> AbMediaResponse:
        def compile_request(request: AbMediaRequest, channel: Channel):
            user_auth = channel._get_message_auth(session.auth)
            request_serialized = ab_media_compiler.compile_ab_media_request(
                request,
                serialize_length_delimited(user_auth),
            )
            return bytes(request_serialized)

        def decompile_response(responses: List[bytes]) -> AbMediaResponse:
            if len(responses) != 1:
                raise Exception("Malformed response")
            response = ab_media_compiler.decompile_ab_media_response(
                request, bytes(responses[0])
            )
            return response

        # TODO: The `endpoint_protocols` should come from DDC as it knows
        # the appropriate supported versions.
        endpoint_protocols = [3, 4, 5, 6]
        protocol = session._get_client_protocol(endpoint_protocols)
        response = session.send_compilable_request(
            compile_request, request, decompile_response, protocol
        )
        return response



from google.protobuf.json_format import MessageToDict

from ...proto import (
    ComputeNodeFormat,
    serialize_length_delimited,
)
from ..node import Node
from .proto import (
    MicrosoftDspWorkerConfiguration,
    SinkInput,
    SegmentInfo,
    MemberInfo,
)


class DataSinkMicrosoftDsp(Node):
    """
    Compute node that exports data to Microsoft DSP.
    """

    def __init__(
        self,
        name: str,
        input: SinkInput,
        member_id: str,
        member_name: str,
        segment_short_name: str,
        segment_code: str,
    ) -> None:
        config = MicrosoftDspWorkerConfiguration(
            input=input,
            member_info=MemberInfo(id=member_id, name=member_name),
            segment_info=SegmentInfo(short_name=segment_short_name, code=segment_code),
        )
        config_serialized = serialize_length_delimited(config)
        super().__init__(
            name,
            config=config_serialized,
            enclave_type="decentriq.microsoft-dsp-worker",
            dependencies=[input.dependency],
            output_format=ComputeNodeFormat.RAW,
        )


from ...decoder import MicrosoftDspWorkerDecoder

__all__ = [
    "DataSinkMicrosoftDsp",
    "MicrosoftDspWorkerDecoder",
]



from __future__ import annotations
from typing import List, Union
from typing_extensions import Self
from .api import SeedAudience, CustomAudience
from .audiences import AudienceType
from .participant import Participant

class LookalikeAudienceDefinition:
    """
    Class representing the definition of a lookalike audience.
    """

    def __init__(
        self,
        *,
        name: str,
        reach: int,
        exclude_seed_audience: bool,
        source_audience: Union[SeedAudience, CustomAudience],
        shared_with: List[Participant],
    ) -> None:
        """
        Initialize a lookalike audience definition.

        **Parameters**:
        - `name`: Name of the lookalike audience
        - `reach`: The desired reach percentage (1-30)
        - `exclude_seed_audience`: Whether to exclude the seed audience
        - `source_audience`: The source audience to build from
        - `shared_with`: List of participant groups to share with
        """
        self.name = name
        self.reach = reach
        self.exclude_seed_audience = exclude_seed_audience
        self.source_audience = source_audience
        self.kind = "LOOKALIKE"
        self.shared_with = [participant.id for participant in shared_with]

class LookalikeAudienceBuilder:
    """
    Builder for constructing lookalike audience definitions.
    """

    def __init__(
        self,
        *,
        name: str,
        reach: int,
        source_audience: AudienceType,
    ) -> None:
        """
        Initialise the lookalike audience builder.

        **Parameters**:
        - `name`: Name of the lookalike audience.
        - `reach`: The desired reach of the lookalike audience expressed as a percentage between 1-30.
        - `source_audience_name`: Name of the source audience that the lookalike audience will be built from.
        """
        if not (0 <= reach <= 30):
            raise Exception(f"Reach value {reach} is not in range 0 to 30")

        self.name = name
        self.reach = reach
        self.source_audience = source_audience
        self.exclude_seed_audience = False
        self.shared_with = []

    def with_exclude_seed_audience(self) -> Self:
        """
        Exclude the seed audience from the lookalike audience.

        **Returns**:
        - The updated lookalike audience builder
        """
        self.exclude_seed_audience = True
        return self

    def with_share_with_participants(self, participants: List[Participant]) -> Self:
        """
        Make the lookalike audience available to the given participants.

        **Parameters**:
        - `participants`: The participants to share the lookalike audience with

        **Returns**:
        - The updated lookalike audience builder
        """
        self.shared_with = participants
        return self

    def build(self) -> LookalikeAudienceDefinition:
        """
        Build the lookalike audience definition.

        **Returns**:
        - The lookalike audience definition
        """
        return LookalikeAudienceDefinition(
            name=self.name,
            reach=self.reach,
            exclude_seed_audience=self.exclude_seed_audience,
            source_audience=self.source_audience,
            shared_with=self.shared_with,
        )
